Summary: Condor: High Throughput Computing
Name: condor
Version: 7.0.4
Release: 4%{?dist}
License: ASL 2.0
Group: Applications/System
URL: http://www.cs.wisc.edu/condor/
# The upstream Condor source tarball contains some source that cannot
# be shipped as well as extraneous copies of packages the source
# depends on. Additionally, the upstream Condor source requires a
# click-through license. Once you have downloaded the source from:
#   http://parrot.cs.wisc.edu/v7.0.license.html
# you should process it with generate-tarball.sh:
#   ./generate-tarball.sh 7.0.4
# MD5Sum of upstream source:
#   06eec3ae274b66d233ad050a047f3c91  condor_src-7.0.0-all-all.tar.gz
#   e59fa49468ea8825628585a958e2f8e0  condor_src-7.0.1-all-all.tar.gz
#   b08743cfa2e87adbcda042896e8ef537  condor_src-7.0.2-all-all.tar.gz
#   5f326ad522b63eacf34c6c563cf46910  condor_src-7.0.4-all-all.tar.gz
# Note: The md5sum of each generated tarball may be different
Source0: condor-7.0.4-95033-RH.tar.gz
Source1: generate-tarball.sh
Patch0: Integration-Branch.patch
Patch1: workfetch-binary-tests.patch
BuildRoot: %(mktemp -ud %{_tmppath}/%{name}-%{version}-%{release}-XXXXXX)

%if 0%{?rhel} != 4
BuildRequires: imake
BuildRequires: krb5-devel
%endif
BuildRequires: flex
BuildRequires: byacc
BuildRequires: tcsh
BuildRequires: pcre-devel
BuildRequires: postgresql-devel
BuildRequires: openssl-devel
BuildRequires: gsoap-devel >= 2.7.10-2
BuildRequires: bind-utils
BuildRequires: m4
BuildRequires: autoconf
BuildRequires: classads-devel

%if 0%{?rhel} != 4
Requires: krb5-libs
%endif
Requires: pcre
Requires: postgresql-libs
Requires: openssl
Requires: gsoap >= 2.7.10-2
Requires: mailx
Requires: classads
Requires: python >= 2.2

Requires(pre): shadow-utils

Requires(post):/sbin/chkconfig
Requires(preun):/sbin/chkconfig
Requires(preun):/sbin/service
Requires(postun):/sbin/service

#Provides: user(condor) = 43
#Provides: group(condor) = 43


%description
Condor is a specialized workload management system for
compute-intensive jobs. Like other full-featured batch systems, Condor
provides a job queueing mechanism, scheduling policy, priority scheme,
resource monitoring, and resource management. Users submit their
serial or parallel jobs to Condor, Condor places them into a queue,
chooses when and where to run the jobs based upon a policy, carefully
monitors their progress, and ultimately informs the user upon
completion.

This package contains (part of) a Technology Preview for Red Hat
Enterprise MRG Grid. Please visit
http://www.redhat.com/support/service/ for details on the Red Hat
support policies.

%package static
Summary: Headers and libraries for interacting with Condor
Group: Development/System
Requires: %name = %version-%release


%description static
Headers and libraries for interacting with Condor and its components.


%package test
Summary: Condor testing utilities
Group: Development/System
Requires: %name = %version-%release


%description test
Test tools and scripts to verify Condor's functionality.


%pre
getent group condor >/dev/null || groupadd -g 64 -r condor
getent passwd condor >/dev/null || \
  useradd -u 64 -r -g condor -d %_var/lib/condor -s /sbin/nologin \
    -c "Owner of Condor Daemons" condor
exit 0


%prep
%setup -q
%patch0 -p1
%patch1 -p0


%build
%if 0%{?rhel} != 4
# set USE_OLD_IMAKE to anything so condor_imake will use the system
# installed imake instead of building its own
USE_OLD_IMAKE=YES
export USE_OLD_IMAKE
%endif

# Condor does not like to be built with -O2 to begin with, and it
# appears to trigger a bug in GCC 4.3.0, so for the time being -O2 is
# banished from C*FLAGS
%define optflags %(rpm --eval '%%optflags' | sed 's|-O2||g')

cd src
# Must regenerate configure script from configure.ac because of
# patches to configure.ac
./build_init
%configure --with-buildid=RH-%{version}-%{release} \
   --enable-proper \
   --disable-full-port \
   --disable-gcc-version-check \
   --disable-glibc-version-check \
   --disable-static \
   --disable-rpm \
   --without-zlib \
   --with-openssl \
%if 0%{?rhel} != 4
   --with-krb5 \
%else
   --without-krb5 \
%endif
   --with-postgresql \
   --with-gsoap \
   --with-classads \
   --with-man=$PWD/../externals/bundles/man/current

# SMP_NUM_JOBS must be set properly to pass -j to make
SMP_NUM_JOBS=$(echo %{?_smp_mflags} | sed -e 's/-j\(.*\)/\1/')
#export SMP_NUM_JOBS

# build a releasable tarball
make public

# build the test tools and scripts
make testbin
cd condor_tests
make


%install
# installation happens into a temporary location, this function is
# useful in moving files into their final locations
function populate {
  _dest="$1"; shift; _src="$*"
  mkdir -p "%{buildroot}/$_dest"
  mv $_src "%{buildroot}/$_dest"
}


# this function will copy, instead of move, files to their final locations
function populate_cp {
  _dest="$1"; shift; _src="$*"
  mkdir -p "%{buildroot}/$_dest"
  cp -r $_src "%{buildroot}/$_dest"
}

rm -rf %{buildroot}

# make public creates release tarballs which we will install
oldpwd=$PWD
cd public/v7.0
gzip -cd condor-%{version}-*-dynamic-unstripped.tar.gz | tar x
cd condor-%{version}

PREFIX=%{buildroot}/install

populate install *

cp $PREFIX/etc/examples/condor_config.generic $PREFIX/etc/condor_config

mkdir $PREFIX/local_dir
mkdir -m1777 $PREFIX/local_dir/execute
mkdir -m0755 $PREFIX/local_dir/log
mkdir -m0755 $PREFIX/local_dir/spool

cat >> $PREFIX/local_dir/condor_config.local << EOF
CONDOR_HOST = \$(FULL_HOSTNAME)
COLLECTOR_NAME = Personal Condor
START = TRUE
SUSPEND = FALSE
PREEMPT = FALSE
KILL = FALSE
DAEMON_LIST = COLLECTOR, MASTER, NEGOTIATOR, SCHEDD, STARTD
NEGOTIATOR_INTERVAL = 20
EOF

# this gets around a bug whose fix is not yet merged
echo "TRUST_UID_DOMAIN = TRUE" >> $PREFIX/local_dir/condor_config.local

# used by BLAHP, which is not packaged
rm -rf $PREFIX/libexec/glite
# used by old MPI universe, not packaged (it's rsh, it should die)
rm -rf $PREFIX/libexec/rsh
# this is distributed as chirp_client.c/h and chirp_protocol.h in %_usrsrc
rm $PREFIX/lib/libchirp_client.a
rm $PREFIX/include/chirp_client.h
# checkpoint, reschedule and vacate live in bin/, don't duplicate
rm $PREFIX/sbin/condor_checkpoint
rm $PREFIX/sbin/condor_reschedule
rm $PREFIX/sbin/condor_vacate
# the libcondorapi.so is not properly created, instead of providing it
# we will provide the .a version in a static package
rm $PREFIX/lib/libcondorapi.so
# sbin/condor and uniq_pid_command are pointless hard links
rm $PREFIX/sbin/condor
rm $PREFIX/sbin/uniq_pid_command

# some scripts are examples but have exec bits set anyway
chmod a-x $PREFIX/etc/examples/condor.boot
chmod a-x $PREFIX/etc/examples/lamscript
chmod a-x $PREFIX/etc/examples/mp1script

# here is the actual installation
populate %_mandir/man1 $PREFIX/man/man1/*
populate %_bindir $PREFIX/bin/*
populate %_sbindir $PREFIX/sbin/*
populate %_usrsrc $PREFIX/src/chirp
populate %_sysconfdir/condor $PREFIX/etc/condor_config
populate %_includedir/condor $PREFIX/include/*
populate %_libdir $PREFIX/lib/libcondorapi.a
populate %_datadir/condor $PREFIX/lib/*
populate %_datadir/condor/sql $PREFIX/sql/*
populate %_libexecdir/condor $PREFIX/libexec/*
populate %_var/lib/condor $PREFIX/local_dir/*


# install the testing materials
populate_cp %_libexecdir/condor/test $oldpwd/src/condor_tests
# these are symlinks, so remove them
rm -f %{buildroot}/%_libexecdir/condor/test/condor_tests/safe_append.pl
rm -f %{buildroot}/%_libexecdir/condor/test/condor_tests/batch_test.pl
# remove the [I]Makefiles, source code, and .o files as they're not needed
rm -f %{buildroot}/%_libexecdir/condor/test/condor_tests/*Imakefile*
rm -f %{buildroot}/%_libexecdir/condor/test/condor_tests/*Makefile*
rm -f %{buildroot}/%_libexecdir/condor/test/condor_tests/*.c
rm -f %{buildroot}/%_libexecdir/condor/test/condor_tests/*.C
rm -f %{buildroot}/%_libexecdir/condor/test/condor_tests/*.h
rm -f %{buildroot}/%_libexecdir/condor/test/condor_tests/*.o
rm -f %{buildroot}/%_libexecdir/condor/test/condor_tests/*.tmp
# remove because they are zero-length files
rm -f %{buildroot}/%_libexecdir/condor/test/condor_tests/list_rsc
rm -f %{buildroot}/%_libexecdir/condor/test/condor_tests/list_performance
rm -f %{buildroot}/%_libexecdir/condor/test/condor_tests/compiler_list
rm -f %{buildroot}/%_libexecdir/condor/test/condor_tests/list_stduniv
rm -f %{buildroot}/%_libexecdir/condor/test/condor_tests/list_critical
rm -f %{buildroot}/%_libexecdir/condor/test/condor_tests/list_ckpt
rm -f %{buildroot}/%_libexecdir/condor/test/condor_tests/RuncountChanges
rm -f %{buildroot}/%_libexecdir/condor/test/condor_tests/x_locperrelease_locconfigpostsrc
rm -f %{buildroot}/%_libexecdir/condor/test/condor_tests/x_vancrontab_locconfigpostsrc
# removed because they create a depenedency on the Expect perl module.
# The perl Expect module (RPM generally called perl-Expect) is needed to
# resolve this dependency.
rm -f %{buildroot}/%_libexecdir/condor/test/condor_tests/x_quill_pgsqlinstall.pl
rm -f %{buildroot}/%_libexecdir/condor/test/condor_tests/x_quill_readlineinstall.pl
rm -f %{buildroot}/%_libexecdir/condor/test/condor_tests/job_had_basic.run
rm -f %{buildroot}/%_libexecdir/condor/test/condor_tests/job_replication_basic.run
rm -f %{buildroot}/%_libexecdir/condor/test/condor_tests/job_replication_big.run
populate %_libexecdir/condor/test/testbin_dir $oldpwd/src/testbin_dir/*
# removed because it's not needed.
rm -f %{buildroot}/%_libexecdir/condor/test/testbin_dir/test_condor.log
populate %_libexecdir/condor/test/condor_scripts $oldpwd/src/condor_scripts/Condor*
# removed because it's not needed.
rm -f %{buildroot}/%_libexecdir/condor/test/condor_scripts/CondorConfig.pm
populate %_libexecdir/condor/test/condor_tests $oldpwd/src/condor_scripts/batch_test.pl
# strip the binaries to avoid lint errors
strip %{buildroot}/%_libexecdir/condor/test/condor_tests/*.exe
strip %{buildroot}/%_libexecdir/condor/test/testbin_dir/condor_procapi
strip %{buildroot}/%_libexecdir/condor/test/testbin_dir/condor_sysapi
strip %{buildroot}/%_libexecdir/condor/test/testbin_dir/condor_unit_tests
strip %{buildroot}/%_libexecdir/condor/test/testbin_dir/libcondorapi.so
strip %{buildroot}/%_libexecdir/condor/test/testbin_dir/test_*
# Create a symlink for condor_examples so the default config file can be
# found
ln -s ../../../share/doc/%name-%version/examples %{buildroot}/%_libexecdir/condor/test/condor_examples


# install the lsb init script
install -Dp -m0755 $PREFIX/etc/examples/condor.init %buildroot/%_initrddir/condor

# we must place the config examples in builddir so %doc can find them
mv $PREFIX/etc/examples %_builddir/%name-%version

# delete our temporary workspace
rm -rf $PREFIX


%clean
rm -rf %{buildroot}


%check
# This currently takes hours and can kill your machine...
#cd condor_tests
#make check-seralized


%files
%defattr(-,root,root,-)
%doc LICENSE-2.0.txt examples
%_initrddir/condor
%dir %_sysconfdir/condor/
%config(noreplace) %_sysconfdir/condor/condor_config
%dir %_datadir/condor/
%_datadir/condor/Chirp.jar
%_datadir/condor/CondorJavaInfo.class
%_datadir/condor/CondorJavaWrapper.class
%_datadir/condor/Condor.pm
%_datadir/condor/Execute.pm
%_datadir/condor/FileLock.pm
%_datadir/condor/scimark2lib.jar
%dir %_datadir/condor/sql/
%_datadir/condor/sql/common_createddl.sql
%_datadir/condor/sql/oracle_createddl.sql
%_datadir/condor/sql/oracle_dropddl.sql
%_datadir/condor/sql/pgsql_createddl.sql
%_datadir/condor/sql/pgsql_dropddl.sql
%dir %_datadir/condor/webservice/
%_datadir/condor/webservice/condorAccountant.wsdl
%_datadir/condor/webservice/condorCgahp.wsdl
%_datadir/condor/webservice/condorCollector.wsdl
%_datadir/condor/webservice/condorDagman.wsdl
%_datadir/condor/webservice/condorDbmsd.wsdl
%_datadir/condor/webservice/condorDcskel.wsdl
%_datadir/condor/webservice/condorEventd.wsdl
%_datadir/condor/webservice/condorGridmanager.wsdl
%_datadir/condor/webservice/condorHad.wsdl
%_datadir/condor/webservice/condorJobRouter.wsdl
%_datadir/condor/webservice/condorMaster.wsdl
%_datadir/condor/webservice/condorNegotiator.wsdl
%_datadir/condor/webservice/condorSchedd.wsdl
%_datadir/condor/webservice/condorShadow.wsdl
%_datadir/condor/webservice/condorStartd.wsdl
%_datadir/condor/webservice/condorStarter.wsdl
%_datadir/condor/webservice/condorTransferd.wsdl
%_datadir/condor/webservice/condorVMgahp.wsdl
%dir %_libexecdir/condor/
%_libexecdir/condor/condor_chirp
%_libexecdir/condor/condor_ckpt_probe
%_libexecdir/condor/condor_job_router
%_libexecdir/condor/condor_ssh
%_libexecdir/condor/sshd.sh
%_libexecdir/condor/gridftp_wrapper.sh
%_mandir/man1/condor_advertise.1.gz
%_mandir/man1/condor_checkpoint.1.gz
%_mandir/man1/condor_compile.1.gz
%_mandir/man1/condor_configure.1.gz
%_mandir/man1/condor_config_val.1.gz
%_mandir/man1/condor_findhost.1.gz
%_mandir/man1/condor_glidein.1.gz
%_mandir/man1/condor_history.1.gz
%_mandir/man1/condor_hold.1.gz
%_mandir/man1/condor_master.1.gz
%_mandir/man1/condor_master_off.1.gz
%_mandir/man1/condor_off.1.gz
%_mandir/man1/condor_on.1.gz
%_mandir/man1/condor_preen.1.gz
%_mandir/man1/condor_prio.1.gz
%_mandir/man1/condor_q.1.gz
%_mandir/man1/condor_qedit.1.gz
%_mandir/man1/condor_reconfig.1.gz
%_mandir/man1/condor_reconfig_schedd.1.gz
%_mandir/man1/condor_release.1.gz
%_mandir/man1/condor_reschedule.1.gz
%_mandir/man1/condor_restart.1.gz
%_mandir/man1/condor_rm.1.gz
%_mandir/man1/condor_run.1.gz
%_mandir/man1/condor_stats.1.gz
%_mandir/man1/condor_status.1.gz
%_mandir/man1/condor_store_cred.1.gz
%_mandir/man1/condor_submit.1.gz
%_mandir/man1/condor_submit_dag.1.gz
%_mandir/man1/condor_updates_stats.1.gz
%_mandir/man1/condor_userlog.1.gz
%_mandir/man1/condor_userprio.1.gz
%_mandir/man1/condor_vacate.1.gz
%_mandir/man1/condor_vacate_job.1.gz
%_mandir/man1/condor_check_userlogs.1.gz
%_mandir/man1/condor_chirp.1.gz
%_mandir/man1/condor_cod.1.gz
%_mandir/man1/condor_cold_start.1.gz
%_mandir/man1/condor_cold_stop.1.gz
%_mandir/man1/condor_config_bind.1.gz
%_mandir/man1/condor_convert_history.1.gz
%_mandir/man1/condor_dagman.1.gz
%_mandir/man1/condor_fetchlog.1.gz
%_mandir/man1/condor_load_history.1.gz
%_mandir/man1/condor_transfer_data.1.gz
%_mandir/man1/condor_version.1.gz
%_mandir/man1/condor_wait.1.gz
# bin/condor is a link for checkpoint, reschedule, vacate
%_bindir/condor
%_bindir/condor_load_history
%_bindir/condor_submit_dag
%_bindir/condor_checkpoint
%_bindir/condor_prio
%_bindir/condor_transfer_data
%_bindir/condor_check_userlogs
%_bindir/condor_q
%_bindir/condor_transferer
%_bindir/condor_cod
%_bindir/condor_qedit
%_bindir/condor_userlog
%_bindir/condor_compile
%_bindir/condor_release
%_bindir/condor_userlog_job_counter
%_bindir/condor_config_val
%_bindir/condor_reschedule
%_bindir/condor_userprio
%_bindir/condor_dagman
%_bindir/condor_rm
%_bindir/condor_vacate
%_bindir/condor_dump_history
%_bindir/condor_router_history
%_bindir/condor_router_q
%_bindir/condor_router_rm
%_bindir/condor_run
%_bindir/condor_vacate_job
%_bindir/condor_findhost
%_bindir/condor_stats
%_bindir/condor_version
%_bindir/condor_history
%_bindir/condor_status
%_bindir/condor_wait
%_bindir/condor_hold
%_bindir/condor_submit
%_bindir/condor_glidein
%_sbindir/amazon-gahp
%_sbindir/cleanup_release
# sbin/condor is a link for master_off, off, on, reconfig,
# reconfig_schedd, restart
%_sbindir/condor_advertise
%_sbindir/condor_c-gahp
%_sbindir/condor_c-gahp_worker_thread
%_sbindir/condor_ckpt_server
%_sbindir/condor_cleanup_local
%_sbindir/condor_cold_start
%_sbindir/condor_cold_stop
%_sbindir/condor_collector
%_sbindir/condor_config_bind
%_sbindir/condor_configure
%_sbindir/condor_convert_history
%_sbindir/condor_dbmsd
%_sbindir/condor_fetchlog
%_sbindir/condor_gridshell
%_sbindir/condor_gridmanager
%_sbindir/condor_had
%_sbindir/condor_init
%_sbindir/condor_install
%_sbindir/condor_install_local
%_sbindir/condor_local_start
%_sbindir/condor_local_stop
%_sbindir/condor_master
%_sbindir/condor_master_off
%_sbindir/condor_negotiator
%_sbindir/condor_off
%_sbindir/condor_on
%_sbindir/condor_preen
%_sbindir/condor_procd
%_sbindir/condor_quill
%_sbindir/condor_reconfig
%_sbindir/condor_reconfig_schedd
%_sbindir/condor_replication
%_sbindir/condor_restart
%_sbindir/condor_root_switchboard
%_sbindir/condor_schedd
%_sbindir/condor_shadow
%_sbindir/condor_shadow.std
%_sbindir/condor_startd
%_sbindir/condor_starter
%_sbindir/condor_starter.std
%_sbindir/condor_store_cred
%_sbindir/condor_transferd
%_sbindir/condor_updates_stats
%_sbindir/condor_vm-gahp
%_sbindir/condor_vm_vmware.pl
%_sbindir/condor_vm_xen.sh
%_sbindir/filelock_midwife
%_sbindir/filelock_undertaker
%_sbindir/grid_monitor.sh
%_sbindir/gt4_gahp
%_sbindir/install_release
# sbin/uniq_pid_command is a link for uniq_pid_midwife/undertaker
%_sbindir/unicore_gahp
%_sbindir/uniq_pid_midwife
%_sbindir/uniq_pid_undertaker
%config(noreplace) %_var/lib/condor/condor_config.local
%defattr(-,condor,condor,-)
%dir %_var/lib/condor/
%dir %_var/lib/condor/execute/
%dir %_var/lib/condor/log/
%dir %_var/lib/condor/spool/


%files static
%defattr(-,root,root,-)
%doc LICENSE-2.0.txt
%_libdir/libcondorapi.a
%dir %_includedir/condor/
%_includedir/condor/condor_constants.h
%_includedir/condor/condor_event.h
%_includedir/condor/condor_holdcodes.h
%_includedir/condor/file_lock.h
%_includedir/condor/user_log.c++.h
%doc %_includedir/condor/user_log.README
%dir %_usrsrc/chirp/
%_usrsrc/chirp/chirp_client.c
%_usrsrc/chirp/chirp_client.h
%_usrsrc/chirp/chirp_protocol.h


%files test
%defattr(-,root,root,-)
%doc LICENSE-2.0.txt
%defattr(0775,root,condor,-)
%dir %_libexecdir/condor/test
%dir %_libexecdir/condor/test/condor_tests
%_libexecdir/condor/test/condor_tests/job_core_queue.pl
%defattr(0755,root,root,-)
%dir %_libexecdir/condor/test/condor_scripts
%dir %_libexecdir/condor/test/testbin_dir
%_libexecdir/condor/test/condor_tests/batch_test.pl
%_libexecdir/condor/test/condor_tests/job_condorc_ab_van.pl
%_libexecdir/condor/test/condor_tests/job_condorc_xxx_van.pl
%_libexecdir/condor/test/condor_tests/job_core_args.pl
%_libexecdir/condor/test/condor_tests/job_core_basic_par.pl
%_libexecdir/condor/test/condor_tests/job_core_corefiles.pl
%_libexecdir/condor/test/condor_tests/job_core_crontab.pl
%_libexecdir/condor/test/condor_tests/job_core_err.pl
%_libexecdir/condor/test/condor_tests/job_core_getenv.pl
%_libexecdir/condor/test/condor_tests/job_core_holdkillsig.pl
%_libexecdir/condor/test/condor_tests/job_core_input.pl
%_libexecdir/condor/test/condor_tests/job_core_killsignal.pl
%_libexecdir/condor/test/condor_tests/job_core_leaveinqueue-false_java.pl
%_libexecdir/condor/test/condor_tests/job_core_leaveinqueue-false_sched.pl
%_libexecdir/condor/test/condor_tests/job_core_leaveinqueue-false_van.pl
%_libexecdir/condor/test/condor_tests/job_core_leaveinqueue-true_java.pl
%_libexecdir/condor/test/condor_tests/job_core_leaveinqueue-true_sched.pl
%_libexecdir/condor/test/condor_tests/job_core_leaveinqueue-true_van.pl
%_libexecdir/condor/test/condor_tests/job_core_macros.pl
%_libexecdir/condor/test/condor_tests/job_core_matchlist.pl
%_libexecdir/condor/test/condor_tests/job_core_niceuser.pl
%_libexecdir/condor/test/condor_tests/job_core_onexithold-false_java.pl
%_libexecdir/condor/test/condor_tests/job_core_onexithold-false_local.pl
%_libexecdir/condor/test/condor_tests/job_core_onexithold-false_sched.pl
%_libexecdir/condor/test/condor_tests/job_core_onexithold-false_van.pl
%_libexecdir/condor/test/condor_tests/job_core_onexithold-true_java.pl
%_libexecdir/condor/test/condor_tests/job_core_onexithold-true_local.pl
%_libexecdir/condor/test/condor_tests/job_core_onexithold-true_sched.pl
%_libexecdir/condor/test/condor_tests/job_core_onexithold-true_van.pl
%_libexecdir/condor/test/condor_tests/job_core_onexitrem-false_java.pl
%_libexecdir/condor/test/condor_tests/job_core_onexitrem-false_local.pl
%_libexecdir/condor/test/condor_tests/job_core_onexitrem-false_sched.pl
%_libexecdir/condor/test/condor_tests/job_core_onexitrem-false_van.pl
%_libexecdir/condor/test/condor_tests/job_core_onexitrem-true_java.pl
%_libexecdir/condor/test/condor_tests/job_core_onexitrem-true_local.pl
%_libexecdir/condor/test/condor_tests/job_core_onexitrem-true_sched.pl
%_libexecdir/condor/test/condor_tests/job_core_onexitrem-true_van.pl
%_libexecdir/condor/test/condor_tests/job_core_output.pl
%_libexecdir/condor/test/condor_tests/job_core_perhold-false_java.pl
%_libexecdir/condor/test/condor_tests/job_core_perhold-false_local.pl
%_libexecdir/condor/test/condor_tests/job_core_perhold-false_sched.pl
%_libexecdir/condor/test/condor_tests/job_core_perhold-false_van.pl
%_libexecdir/condor/test/condor_tests/job_core_perhold-true_java.pl
%_libexecdir/condor/test/condor_tests/job_core_perhold-true_local.pl
%_libexecdir/condor/test/condor_tests/job_core_perhold-true_sched.pl
%_libexecdir/condor/test/condor_tests/job_core_perhold-true_van.pl
%_libexecdir/condor/test/condor_tests/job_core_periodicremove_van.pl
%_libexecdir/condor/test/condor_tests/job_core_perrelease-false_java.pl
%_libexecdir/condor/test/condor_tests/job_core_perrelease-false_local.pl
%_libexecdir/condor/test/condor_tests/job_core_perrelease-false_sched.pl
%_libexecdir/condor/test/condor_tests/job_core_perrelease-false_van.pl
%_libexecdir/condor/test/condor_tests/job_core_perrelease-true_java.pl
%_libexecdir/condor/test/condor_tests/job_core_perrelease-true_local.pl
%_libexecdir/condor/test/condor_tests/job_core_perrelease-true_sched.pl
%_libexecdir/condor/test/condor_tests/job_core_perrelease-true_van.pl
%_libexecdir/condor/test/condor_tests/job_core_perremove-false_java.pl
%_libexecdir/condor/test/condor_tests/job_core_perremove-false_local.pl
%_libexecdir/condor/test/condor_tests/job_core_perremove-false_sched.pl
%_libexecdir/condor/test/condor_tests/job_core_perremove-false_van.pl
%_libexecdir/condor/test/condor_tests/job_core_perremove-true_java.pl
%_libexecdir/condor/test/condor_tests/job_core_perremove-true_local.pl
%_libexecdir/condor/test/condor_tests/job_core_perremove-true_sched.pl
%_libexecdir/condor/test/condor_tests/job_core_perremove-true_van.pl
%_libexecdir/condor/test/condor_tests/job_core_priority.pl
%_libexecdir/condor/test/condor_tests/job_core_rmkillsig.pl
%_libexecdir/condor/test/condor_tests/job_core_time-deferral-hold.pl
%_libexecdir/condor/test/condor_tests/job_core_time-deferral.pl
%_libexecdir/condor/test/condor_tests/job_core_time-deferral-remove.pl
%_libexecdir/condor/test/condor_tests/job_dagman_comlog.pl
%_libexecdir/condor/test/condor_tests/job_dagman_fullremove.pl
%_libexecdir/condor/test/condor_tests/job_dagman_monitor.pl
%_libexecdir/condor/test/condor_tests/job_dagman_uncomlog.pl
%_libexecdir/condor/test/condor_tests/job_dagman_xmlcomlog.pl
%_libexecdir/condor/test/condor_tests/job_dagman_xmluncomlog.pl
%_libexecdir/condor/test/condor_tests/job_filexfer_base-input4_van.pl
%_libexecdir/condor/test/condor_tests/job_filexfer_input-onegone_van.pl
%_libexecdir/condor/test/condor_tests/job_filexfer_md5-remote.pl
%_libexecdir/condor/test/condor_tests/job_filexfer_sandbox-empty_van.pl
%_libexecdir/condor/test/condor_tests/job_filexfer_trans-excut-true_van.pl
%_libexecdir/condor/test/condor_tests/job_flocking_to.pl
%_libexecdir/condor/test/condor_tests/job_quill_basic.pl
%_libexecdir/condor/test/condor_tests/job_schedd_restart-holdjobs-ok.pl
%_libexecdir/condor/test/condor_tests/job_schedd_restart-runningjobs-ok.pl
%_libexecdir/condor/test/condor_tests/job_startd_multimatch.pl
%_libexecdir/condor/test/condor_tests/lib_auth_config.run
%_libexecdir/condor/test/condor_tests/lib_auth_protocol-negot.pl
%_libexecdir/condor/test/condor_tests/lib_auth_protocol-negot-prt2.pl
%_libexecdir/condor/test/condor_tests/lib_auth_protocol-negot-prt3.pl
%_libexecdir/condor/test/condor_tests/lib_auth_protocol-negot-prt4.pl
%_libexecdir/condor/test/condor_tests/lib_eventlog.pl
%_libexecdir/condor/test/condor_tests/lib_procapi_cputracking-snapshot.pl
%_libexecdir/condor/test/condor_tests/x_addfullclass.pl
%_libexecdir/condor/test/condor_tests/x_changepatterns.pl
%_libexecdir/condor/test/condor_tests/x_chirpio_mkdata.pl
%_libexecdir/condor/test/condor_tests/x_cmdrunforever.pl
%_libexecdir/condor/test/condor_tests/x_cmdstartonhold.pl
%_libexecdir/condor/test/condor_tests/x_copy_binary_file.pl
%_libexecdir/condor/test/condor_tests/x_cpu_tracking.pl
%_libexecdir/condor/test/condor_tests/x_create_md5data.pl
%_libexecdir/condor/test/condor_tests/x_dagman_boring_prescript.pl
%_libexecdir/condor/test/condor_tests/x_dagman_node-ret.pl
%_libexecdir/condor/test/condor_tests/x_dagman_premonitor.pl
%_libexecdir/condor/test/condor_tests/x_dagman_readflowlog.pl
%_libexecdir/condor/test/condor_tests/x_dagman_readprepostlog.pl
%_libexecdir/condor/test/condor_tests/x_dagman_retry-monitor.pl
%_libexecdir/condor/test/condor_tests/x_doublejeopardy.pl
%_libexecdir/condor/test/condor_tests/x_echo1234.pl
%_libexecdir/condor/test/condor_tests/x_gen_autoscale.pl
%_libexecdir/condor/test/condor_tests/x_general_client.pl
%_libexecdir/condor/test/condor_tests/x_general_server.pl
%_libexecdir/condor/test/condor_tests/x_job_filexfer_stream.pl
%_libexecdir/condor/test/condor_tests/x_job_filexfer_testjob.pl
%_libexecdir/condor/test/condor_tests/x_job_signal-suicide.pl
%_libexecdir/condor/test/condor_tests/x_lib_auth_protocol.pl
%_libexecdir/condor/test/condor_tests/x_lookaround.pl
%_libexecdir/condor/test/condor_tests/x_makeclean.pl
%_libexecdir/condor/test/condor_tests/x_makestorkdag.pl
%_libexecdir/condor/test/condor_tests/x_paralleljob.pl
%_libexecdir/condor/test/condor_tests/x_perf_autoscale.pl
%_libexecdir/condor/test/condor_tests/x_perf_busy.pl
%_libexecdir/condor/test/condor_tests/x_perf_transfer_createdata.pl
%_libexecdir/condor/test/condor_tests/x_perf_transfer_remote.pl
%_libexecdir/condor/test/condor_tests/x_pid_tracking.pl
%_libexecdir/condor/test/condor_tests/x_print-args-and-env.pl
%_libexecdir/condor/test/condor_tests/x_quill_buildperlmods.pl
%_libexecdir/condor/test/condor_tests/x_quill_pgsqlstop.pl
%_libexecdir/condor/test/condor_tests/x_read_binary_file.pl
%_libexecdir/condor/test/condor_tests/x_readqueuelog.pl
%_libexecdir/condor/test/condor_tests/x_reclassimakefile.pl
%_libexecdir/condor/test/condor_tests/x_renamebypattern.pl
%_libexecdir/condor/test/condor_tests/x_rename_inouterr.pl
%_libexecdir/condor/test/condor_tests/x_renametool.pl
%_libexecdir/condor/test/condor_tests/x_returnquick.pl
%_libexecdir/condor/test/condor_tests/x_runstorkdag.pl
%_libexecdir/condor/test/condor_tests/x_runtests.pl
%_libexecdir/condor/test/condor_tests/x_sanitysubmit.pl
%_libexecdir/condor/test/condor_tests/x_sleep.pl
%_libexecdir/condor/test/condor_tests/x_striplines.pl
%_libexecdir/condor/test/condor_tests/x_test_md5data.pl
%_libexecdir/condor/test/condor_tests/x_time.pl
%_libexecdir/condor/test/condor_tests/fetch_work-basic.pl
%_libexecdir/condor/test/condor_tests/fort-gen.pl
%_libexecdir/condor/test/condor_tests/job_core_perrelease_local.pl
%_libexecdir/condor/test/condor_tests/x_java_CondorEcho.class
%_libexecdir/condor/test/condor_tests/x_java_CopyFilePlus.class
%_libexecdir/condor/test/condor_tests/x_java_Property.class
%_libexecdir/condor/test/condor_tests/x_java_ReadStdin.class
%_libexecdir/condor/test/condor_tests/x_java_RenameFile.class
%_libexecdir/condor/test/condor_tests/x_java_Sleep.class
%_libexecdir/condor/test/condor_tests/x_perf_Busy.class
%_libexecdir/condor/test/condor_tests/x_perf_CopyFile.class
%_libexecdir/condor/test/condor_tests/x_perf_Sleep.class
%_libexecdir/condor/test/condor_tests/alwaysfail.run
%_libexecdir/condor/test/condor_tests/cmd_q_multi.run
%_libexecdir/condor/test/condor_tests/cmd_q_shows-analyze.run
%_libexecdir/condor/test/condor_tests/cmd_q_shows-better-analyze.run
%_libexecdir/condor/test/condor_tests/cmd_q_shows-cputime.run
%_libexecdir/condor/test/condor_tests/cmd_q_shows-format.run
%_libexecdir/condor/test/condor_tests/cmd_q_shows-global.run
%_libexecdir/condor/test/condor_tests/cmd_q_shows-hold.run
%_libexecdir/condor/test/condor_tests/cmd_q_shows-name.run
%_libexecdir/condor/test/condor_tests/cmd_q_shows-pool.run
%_libexecdir/condor/test/condor_tests/cmd_q_shows-run.run
%_libexecdir/condor/test/condor_tests/cmd_q_shows-sub.run
%_libexecdir/condor/test/condor_tests/cmd_q_shows-xml.run
%_libexecdir/condor/test/condor_tests/cmd_status_shows-any.run
%_libexecdir/condor/test/condor_tests/cmd_status_shows-avail.run
%_libexecdir/condor/test/condor_tests/cmd_status_shows-claim.run
%_libexecdir/condor/test/condor_tests/cmd_status_shows-constraint.run
%_libexecdir/condor/test/condor_tests/cmd_status_shows-format.run
%_libexecdir/condor/test/condor_tests/cmd_status_shows-help.run
%_libexecdir/condor/test/condor_tests/cmd_status_shows-master.run
%_libexecdir/condor/test/condor_tests/cmd_status_shows-negotiator.run
%_libexecdir/condor/test/condor_tests/cmd_status_shows-schedd.run
%_libexecdir/condor/test/condor_tests/cmd_status_shows-startd.run
%_libexecdir/condor/test/condor_tests/cmd_status_shows-state.run
%_libexecdir/condor/test/condor_tests/cmd_status_shows-submitters.run
%_libexecdir/condor/test/condor_tests/cmd_wait_shows-all.run
%_libexecdir/condor/test/condor_tests/cmd_wait_shows-base.run
%_libexecdir/condor/test/condor_tests/cmd_wait_shows-notimeout.run
%_libexecdir/condor/test/condor_tests/cmd_wait_shows-partial.run
%_libexecdir/condor/test/condor_tests/cmd_wait_shows-timeout.run
%_libexecdir/condor/test/condor_tests/job_ckpt_combo-sanity_std.run
%_libexecdir/condor/test/condor_tests/job_ckpt_constructor_std.run
%_libexecdir/condor/test/condor_tests/job_ckpt_dup_std.run
%_libexecdir/condor/test/condor_tests/job_ckpt_env_std.run
%_libexecdir/condor/test/condor_tests/job_ckpt_f-areauc_std.run
%_libexecdir/condor/test/condor_tests/job_ckpt_f-floats_std.run
%_libexecdir/condor/test/condor_tests/job_ckpt_f-integers_std.run
%_libexecdir/condor/test/condor_tests/job_ckpt_floats-async_std.run
%_libexecdir/condor/test/condor_tests/job_ckpt_floats_std.run
%_libexecdir/condor/test/condor_tests/job_ckpt_f-printer_std.run
%_libexecdir/condor/test/condor_tests/job_ckpt_f-reader_std.run
%_libexecdir/condor/test/condor_tests/job_ckpt_getrusage-loop_std.run
%_libexecdir/condor/test/condor_tests/job_ckpt_gettimeofday_std.run
%_libexecdir/condor/test/condor_tests/job_ckpt_integers_std.run
%_libexecdir/condor/test/condor_tests/job_ckpt_io-async_std.run
%_libexecdir/condor/test/condor_tests/job_ckpt_io-buffer-async_std.run
%_libexecdir/condor/test/condor_tests/job_ckpt_longjmp_std.run
%_libexecdir/condor/test/condor_tests/job_ckpt_memory-file_std.run
%_libexecdir/condor/test/condor_tests/job_ckpt_open-async-ckpt_std.run
%_libexecdir/condor/test/condor_tests/job_ckpt_open-N-parallel_std.run
%_libexecdir/condor/test/condor_tests/job_ckpt_signals_std.run
%_libexecdir/condor/test/condor_tests/job_ckpt_socket-support_std.run
%_libexecdir/condor/test/condor_tests/job_ckpt_stack_std.run
%_libexecdir/condor/test/condor_tests/job_condorc_abc_van.run
%_libexecdir/condor/test/condor_tests/job_condorc_ab_van.run
%_libexecdir/condor/test/condor_tests/job_core_args_java.run
%_libexecdir/condor/test/condor_tests/job_core_args_sched.run
%_libexecdir/condor/test/condor_tests/job_core_args_van.run
%_libexecdir/condor/test/condor_tests/job_core_basic_par.run
%_libexecdir/condor/test/condor_tests/job_core_basic-security_par.run
%_libexecdir/condor/test/condor_tests/job_core_bigenv_sched.run
%_libexecdir/condor/test/condor_tests/job_core_bigenv_std.run
%_libexecdir/condor/test/condor_tests/job_core_bigenv_van.run
%_libexecdir/condor/test/condor_tests/job_core_compressfiles_std.run
%_libexecdir/condor/test/condor_tests/job_core_copytospool_van.run
%_libexecdir/condor/test/condor_tests/job_core_coredump_std.run
%_libexecdir/condor/test/condor_tests/job_core_coredump_van.run
%_libexecdir/condor/test/condor_tests/job_core_corefiles_sched.run
%_libexecdir/condor/test/condor_tests/job_core_corefiles_van.run
%_libexecdir/condor/test/condor_tests/job_core-cpp_exception_std.run
%_libexecdir/condor/test/condor_tests/job_core-cpp_mem-alloc_std.run
%_libexecdir/condor/test/condor_tests/job_core_crontab_local.run
%_libexecdir/condor/test/condor_tests/job_core_crontab_van.run
%_libexecdir/condor/test/condor_tests/job_core_doublejeopardy_sched.run
%_libexecdir/condor/test/condor_tests/job_core_doublejeopardy_van.run
%_libexecdir/condor/test/condor_tests/job_core_env_java.run
%_libexecdir/condor/test/condor_tests/job_core_env_sched.run
%_libexecdir/condor/test/condor_tests/job_core_env_van.run
%_libexecdir/condor/test/condor_tests/job_core_err_java.run
%_libexecdir/condor/test/condor_tests/job_core_err_sched.run
%_libexecdir/condor/test/condor_tests/job_core_err_van.run
%_libexecdir/condor/test/condor_tests/job_core_getenv_van.run
%_libexecdir/condor/test/condor_tests/job_core_hold_java.run
%_libexecdir/condor/test/condor_tests/job_core_holdkillsig_sched.run
%_libexecdir/condor/test/condor_tests/job_core_holdrelease_sched.run
%_libexecdir/condor/test/condor_tests/job_core_holdrelease_van.run
%_libexecdir/condor/test/condor_tests/job_core_hold_sched.run
%_libexecdir/condor/test/condor_tests/job_core_hold_van.run
%_libexecdir/condor/test/condor_tests/job_core_initialdir_java.run
%_libexecdir/condor/test/condor_tests/job_core_initialdir_sched.run
%_libexecdir/condor/test/condor_tests/job_core_initialdir_van.run
%_libexecdir/condor/test/condor_tests/job_core_input_java.run
%_libexecdir/condor/test/condor_tests/job_core_input_sched.run
%_libexecdir/condor/test/condor_tests/job_core_input_van.run
%_libexecdir/condor/test/condor_tests/job_core_killsignal_java.run
%_libexecdir/condor/test/condor_tests/job_core_killsignal_sched.run
%_libexecdir/condor/test/condor_tests/job_core_killsignal_van.run
%_libexecdir/condor/test/condor_tests/job_core_leaveinqueue_java.run
%_libexecdir/condor/test/condor_tests/job_core_leaveinqueue_sched.run
%_libexecdir/condor/test/condor_tests/job_core_leaveinqueue_van.run
%_libexecdir/condor/test/condor_tests/job_core_macros-dollardollar_van.run
%_libexecdir/condor/test/condor_tests/job_core_macros_java.run
%_libexecdir/condor/test/condor_tests/job_core_macros_sched.run
%_libexecdir/condor/test/condor_tests/job_core_matchlist_van.run
%_libexecdir/condor/test/condor_tests/job_core_max-running_local.run
%_libexecdir/condor/test/condor_tests/job_core_niceuser_van.run
%_libexecdir/condor/test/condor_tests/job_core_onexithold_java.run
%_libexecdir/condor/test/condor_tests/job_core_onexithold_local.run
%_libexecdir/condor/test/condor_tests/job_core_onexithold_sched.run
%_libexecdir/condor/test/condor_tests/job_core_onexithold_van.run
%_libexecdir/condor/test/condor_tests/job_core_onexitrem_java.run
%_libexecdir/condor/test/condor_tests/job_core_onexitrem_local.run
%_libexecdir/condor/test/condor_tests/job_core_onexitrem_sched.run
%_libexecdir/condor/test/condor_tests/job_core_onexitrem_van.run
%_libexecdir/condor/test/condor_tests/job_core_output_java.run
%_libexecdir/condor/test/condor_tests/job_core_output_sched.run
%_libexecdir/condor/test/condor_tests/job_core_output_van.run
%_libexecdir/condor/test/condor_tests/job_core_perhold_java.run
%_libexecdir/condor/test/condor_tests/job_core_perhold_local.run
%_libexecdir/condor/test/condor_tests/job_core_perhold_sched.run
%_libexecdir/condor/test/condor_tests/job_core_perhold_van.run
%_libexecdir/condor/test/condor_tests/job_core_periodicremove_van.run
%_libexecdir/condor/test/condor_tests/job_core_perrelease_java.run
%_libexecdir/condor/test/condor_tests/job_core_perrelease_local.run
%_libexecdir/condor/test/condor_tests/job_core_perrelease_sched.run
%_libexecdir/condor/test/condor_tests/job_core_perrelease_van.run
%_libexecdir/condor/test/condor_tests/job_core_perremove_java.run
%_libexecdir/condor/test/condor_tests/job_core_perremove_local.run
%_libexecdir/condor/test/condor_tests/job_core_perremove_sched.run
%_libexecdir/condor/test/condor_tests/job_core_perremove_van.run
%_libexecdir/condor/test/condor_tests/job_core_plus_java.run
%_libexecdir/condor/test/condor_tests/job_core_plus_sched.run
%_libexecdir/condor/test/condor_tests/job_core_plus_van.run
%_libexecdir/condor/test/condor_tests/job_core_priority_java.run
%_libexecdir/condor/test/condor_tests/job_core_priority_van.run
%_libexecdir/condor/test/condor_tests/job_core_queue_sched.run
%_libexecdir/condor/test/condor_tests/job_core_remote-initialdir_van.run
%_libexecdir/condor/test/condor_tests/job_core_rmkillsig_sched.run
%_libexecdir/condor/test/condor_tests/job_core_sh-loop_van.run
%_libexecdir/condor/test/condor_tests/job_core_signal-suicide_sched.run
%_libexecdir/condor/test/condor_tests/job_core_signal-suicide_van.run
%_libexecdir/condor/test/condor_tests/job_core_time-deferral-hold_local.run
%_libexecdir/condor/test/condor_tests/job_core_time-deferral-hold_van.run
%_libexecdir/condor/test/condor_tests/job_core_time-deferral_local.run
%_libexecdir/condor/test/condor_tests/job_core_time-deferral-remove_local.run
%_libexecdir/condor/test/condor_tests/job_core_time-deferral-remove_van.run
%_libexecdir/condor/test/condor_tests/job_core_time-deferral_van.run
%_libexecdir/condor/test/condor_tests/job_dagman_basic.run
%_libexecdir/condor/test/condor_tests/job_dagman_comlog.run
%_libexecdir/condor/test/condor_tests/job_dagman_fullremove.run
%_libexecdir/condor/test/condor_tests/job_dagman_maxpostscripts.run
%_libexecdir/condor/test/condor_tests/job_dagman_maxprescripts.run
%_libexecdir/condor/test/condor_tests/job_dagman_prepost.run
%_libexecdir/condor/test/condor_tests/job_dagman_retry.run
%_libexecdir/condor/test/condor_tests/job_dagman_stork-file-file.run
%_libexecdir/condor/test/condor_tests/job_dagman_stork-remove.run
%_libexecdir/condor/test/condor_tests/job_dagman_throttle.run
%_libexecdir/condor/test/condor_tests/job_dagman_uncomlog.run
%_libexecdir/condor/test/condor_tests/job_dagman_unlessexit.run
%_libexecdir/condor/test/condor_tests/job_dagman_xmlcomlog.run
%_libexecdir/condor/test/condor_tests/job_dagman_xmluncomlog.run
%_libexecdir/condor/test/condor_tests/job_filexfer_base-input1_van.run
%_libexecdir/condor/test/condor_tests/job_filexfer_base-input4_van.run
%_libexecdir/condor/test/condor_tests/job_filexfer_base_van.run
%_libexecdir/condor/test/condor_tests/job_filexfer_basic_van.run
%_libexecdir/condor/test/condor_tests/job_filexfer_input-onegone_van.run
%_libexecdir/condor/test/condor_tests/job_filexfer_limitback_van.run
%_libexecdir/condor/test/condor_tests/job_filexfer_md5_java.run
%_libexecdir/condor/test/condor_tests/job_filexfer_md5-remote_van.run
%_libexecdir/condor/test/condor_tests/job_filexfer_minus1_van.run
%_libexecdir/condor/test/condor_tests/job_filexfer_output_van.run
%_libexecdir/condor/test/condor_tests/job_filexfer_output-withvacate_van.run
%_libexecdir/condor/test/condor_tests/job_filexfer_sandbox-empty_van.run
%_libexecdir/condor/test/condor_tests/job_filexfer_streamerr_van.run
%_libexecdir/condor/test/condor_tests/job_filexfer_streamout_van.run
%_libexecdir/condor/test/condor_tests/job_filexfer_trans-excut-true_van.run
%_libexecdir/condor/test/condor_tests/job_filexfer_trans-nodflts_van.run
%_libexecdir/condor/test/condor_tests/job_filexfer_twosets_van.run
%_libexecdir/condor/test/condor_tests/job_filexfer_whento-base_van.run
%_libexecdir/condor/test/condor_tests/job_filexfer_whento-simpleinput_van.run
%_libexecdir/condor/test/condor_tests/job_filexfer_whento-withinput_van.run
%_libexecdir/condor/test/condor_tests/job_flocking_to.run
%_libexecdir/condor/test/condor_tests/job_ligo_x86-64-chkpttst.run
%_libexecdir/condor/test/condor_tests/job_quill_basic.run
%_libexecdir/condor/test/condor_tests/job_rsc_all-syscalls_std.run
%_libexecdir/condor/test/condor_tests/job_rsc_binary-io_std.run
%_libexecdir/condor/test/condor_tests/job_rsc_fcntl_std.run
%_libexecdir/condor/test/condor_tests/job_rsc_f-direct-write_std.run
%_libexecdir/condor/test/condor_tests/job_rsc_fgets_std.run
%_libexecdir/condor/test/condor_tests/job_rsc_fread_std.run
%_libexecdir/condor/test/condor_tests/job_rsc_fstream_std.run
%_libexecdir/condor/test/condor_tests/job_rsc_ftell_std.run
%_libexecdir/condor/test/condor_tests/job_rsc_getdirentries_std.run
%_libexecdir/condor/test/condor_tests/job_rsc_hello_std.run
%_libexecdir/condor/test/condor_tests/job_rsc_open-N-serial_std.run
%_libexecdir/condor/test/condor_tests/job_rsc_stat_std.run
%_libexecdir/condor/test/condor_tests/job_rsc_true-false_std.run
%_libexecdir/condor/test/condor_tests/job_rsc_truncate_std.run
%_libexecdir/condor/test/condor_tests/job_rsc_zero-calloc_std.run
%_libexecdir/condor/test/condor_tests/job_schedd_job-tracking_van.run
%_libexecdir/condor/test/condor_tests/job_schedd_restart-holdjobs-ok.run
%_libexecdir/condor/test/condor_tests/job_schedd_restart-runningjobs-ok.run
%_libexecdir/condor/test/condor_tests/job_startd_multimatch.run
%_libexecdir/condor/test/condor_tests/job_stork_file-file.run
%_libexecdir/condor/test/condor_tests/lib_auth_protocol-ctb.run
%_libexecdir/condor/test/condor_tests/lib_auth_protocol-fs.run
%_libexecdir/condor/test/condor_tests/lib_auth_protocol-gsi.run
%_libexecdir/condor/test/condor_tests/lib_auth_protocol-krb.run
%_libexecdir/condor/test/condor_tests/lib_auth_protocol-negot-prt2.run
%_libexecdir/condor/test/condor_tests/lib_auth_protocol-negot-prt3.run
%_libexecdir/condor/test/condor_tests/lib_auth_protocol-negot-prt4.run
%_libexecdir/condor/test/condor_tests/lib_auth_protocol-negot.run
%_libexecdir/condor/test/condor_tests/lib_auth_protocol-pw.run
%_libexecdir/condor/test/condor_tests/lib_auth_protocol-ssl.run
%_libexecdir/condor/test/condor_tests/lib_chirpio_van.run
%_libexecdir/condor/test/condor_tests/lib_classads.run
%_libexecdir/condor/test/condor_tests/lib_eventlog.run
%_libexecdir/condor/test/condor_tests/lib_eventlog-xml.run
%_libexecdir/condor/test/condor_tests/lib_procapi_cputracking-snapshot.run
%_libexecdir/condor/test/condor_tests/lib_procapi_pidtracking-byenv.run
%_libexecdir/condor/test/condor_tests/lib_procapi_pidtracking-snapshot.run
%_libexecdir/condor/test/condor_tests/lib_procapi.run
%_libexecdir/condor/test/condor_tests/lib_sysapi.run
%_libexecdir/condor/test/condor_tests/lib_unit_tests.run
%_libexecdir/condor/test/condor_tests/lib_userlog.run
%_libexecdir/condor/test/condor_tests/perf_busy_lynn_100_100_500_sched.run
%_libexecdir/condor/test/condor_tests/perf_jobs_sue_10_10_30_van.run
%_libexecdir/condor/test/condor_tests/perf_xfer_deb_10_10_30_van.run
%_libexecdir/condor/test/condor_tests/soap_job_tests.run
%_libexecdir/condor/test/condor_tests/fetch_work-basic.run
%_libexecdir/condor/test/condor_tests/job_condorc_xxx_van.sh
%_libexecdir/condor/test/condor_tests/job_core_sh-loop_van.sh
%_libexecdir/condor/test/condor_tests/x_trapsig.sh
%_libexecdir/condor/test/condor_tests/job_core_bigenv.exe
%_libexecdir/condor/test/condor_tests/lib_chirpio.exe
%_libexecdir/condor/test/condor_tests/x_dumpcore.exe
%_libexecdir/condor/test/condor_tests/x_read_joblog.exe
%_libexecdir/condor/test/condor_tests/x_return-n.exe
%_libexecdir/condor/test/condor_tests/x_tightloop.exe
%_libexecdir/condor/test/condor_tests/x_trapsig.exe
%_libexecdir/condor/test/condor_tests/x_write_joblog_events.exe
%_libexecdir/condor/test/condor_tests/x_write_joblog.exe
%_libexecdir/condor/test/condor_tests/job_core_priority2.template
%_libexecdir/condor/test/condor_tests/job_dagman_prepost-prehello.template
%_libexecdir/condor/test/condor_tests/job_dagman_maxpostscripts-checkin.template
%_libexecdir/condor/test/condor_tests/x_perf_autoscale_run_template
%_libexecdir/condor/test/condor_tests/job_dagman_prepost-posthello.template
%_libexecdir/condor/test/condor_tests/job_dagman_maxprescripts-checkin.template
%_libexecdir/condor/test/testbin_dir/condor_procapi
%_libexecdir/condor/test/testbin_dir/condor_sysapi
%_libexecdir/condor/test/testbin_dir/condor_test_auth
%_libexecdir/condor/test/testbin_dir/condor_unit_tests
%_libexecdir/condor/test/testbin_dir/test_classads
%_libexecdir/condor/test/testbin_dir/test_libcondorapi
%_libexecdir/condor/test/testbin_dir/test_libcondorapi_shared
%defattr(0664,root,condor,-)
%_libexecdir/condor/test/condor_tests/job_core_queue_sched.cmd
%_libexecdir/condor/test/condor_tests/job_filexfer_output-withvacate_van.cmd
%_libexecdir/condor/test/condor_tests/job_filexfer_minus1_van.cmd
%_libexecdir/condor/test/condor_tests/job_filexfer_base-input1_van.cmd
%_libexecdir/condor/test/condor_tests/job_filexfer_base-input4_van.cmd
%_libexecdir/condor/test/condor_tests/job_filexfer_base_van.cmd
%_libexecdir/condor/test/condor_tests/job_filexfer_input-onegone_van.cmd
%_libexecdir/condor/test/condor_tests/job_filexfer_limitback_van.cmd
%_libexecdir/condor/test/condor_tests/job_filexfer_whento-base_van.cmd
%_libexecdir/condor/test/condor_tests/job_filexfer_whento-simpleinput_van.cmd
%_libexecdir/condor/test/condor_tests/job_filexfer_whento-withinput_van.cmd
%_libexecdir/condor/test/condor_tests/job_filexfer_output_van.cmd
%defattr(0644,root,root,-)
%_libexecdir/condor/test/condor_examples
%_libexecdir/condor/test/condor_scripts/CondorPersonal.pm
%_libexecdir/condor/test/condor_scripts/Condor.pm
%_libexecdir/condor/test/condor_scripts/CondorTest.pm
%_libexecdir/condor/test/condor_tests/cmd_q_multi.template
%_libexecdir/condor/test/condor_tests/cmd_q_shows-analyze.cmd
%_libexecdir/condor/test/condor_tests/cmd_q_shows-better-analyze.cmd
%_libexecdir/condor/test/condor_tests/cmd_q_shows-cputime.cmd
%_libexecdir/condor/test/condor_tests/cmd_q_shows-format.cmd
%_libexecdir/condor/test/condor_tests/cmd_q_shows-hold.cmd
%_libexecdir/condor/test/condor_tests/cmd_q_shows-run.cmd
%_libexecdir/condor/test/condor_tests/cmd_q_shows-sub.cmd
%_libexecdir/condor/test/condor_tests/cmd_q_shows-xml.cmd
%_libexecdir/condor/test/condor_tests/CondorPersonal.pm
%_libexecdir/condor/test/condor_tests/Condor.pm
%_libexecdir/condor/test/condor_tests/CondorTest.pm
%_libexecdir/condor/test/condor_tests/job_ckpt_combo-sanity_std.cmd
%_libexecdir/condor/test/condor_tests/job_ckpt_constructor_std.cmd
%_libexecdir/condor/test/condor_tests/job_ckpt_dup_std.cmd
%_libexecdir/condor/test/condor_tests/job_ckpt_env_std.cmd
%_libexecdir/condor/test/condor_tests/job_ckpt_f-areauc_std.cmd
%_libexecdir/condor/test/condor_tests/job_ckpt_f-areauc_std.f
%_libexecdir/condor/test/condor_tests/job_ckpt_f-floats_std.cmd
%_libexecdir/condor/test/condor_tests/job_ckpt_f-floats_std.f
%_libexecdir/condor/test/condor_tests/job_ckpt_f-integers_std.cmd
%_libexecdir/condor/test/condor_tests/job_ckpt_f-integers_std.f
%_libexecdir/condor/test/condor_tests/job_ckpt_floats-async_std.cmd
%_libexecdir/condor/test/condor_tests/job_ckpt_floats_std.cmd
%_libexecdir/condor/test/condor_tests/job_ckpt_f-printer_std.cmd
%_libexecdir/condor/test/condor_tests/job_ckpt_f-printer_std.f
%_libexecdir/condor/test/condor_tests/job_ckpt_f-reader_std.cmd
%_libexecdir/condor/test/condor_tests/job_ckpt_f-reader_std.f
%_libexecdir/condor/test/condor_tests/job_ckpt_f-reader_std.in
%_libexecdir/condor/test/condor_tests/job_ckpt_getrusage-loop_std.cmd
%_libexecdir/condor/test/condor_tests/job_ckpt_gettimeofday_std.cmd
%_libexecdir/condor/test/condor_tests/job_ckpt_integers_std.cmd
%_libexecdir/condor/test/condor_tests/job_ckpt_io-async_std.cmd
%_libexecdir/condor/test/condor_tests/job_ckpt_io-buffer-async_std.cmd
%_libexecdir/condor/test/condor_tests/job_ckpt_longjmp_std.cmd
%_libexecdir/condor/test/condor_tests/job_ckpt_memory-file_std.cmd
%_libexecdir/condor/test/condor_tests/job_ckpt_open-async-ckpt_std.cmd
%_libexecdir/condor/test/condor_tests/job_ckpt_open-N-parallel_std.cmd
%_libexecdir/condor/test/condor_tests/job_ckpt_signals_std.cmd
%_libexecdir/condor/test/condor_tests/job_ckpt_socket-support_std.cmd
%_libexecdir/condor/test/condor_tests/job_ckpt_stack_std.cmd
%_libexecdir/condor/test/condor_tests/job_condorc_abc_van.template
%_libexecdir/condor/test/condor_tests/job_condorc_ab_van.template
%_libexecdir/condor/test/condor_tests/job_core_args_java.cmd
%_libexecdir/condor/test/condor_tests/job_core_args_sched.cmd
%_libexecdir/condor/test/condor_tests/job_core_args_van.cmd
%_libexecdir/condor/test/condor_tests/job_core_basic_par.template
%_libexecdir/condor/test/condor_tests/job_core_bigenv_sched.cmd
%_libexecdir/condor/test/condor_tests/job_core_bigenv_std.cmd
%_libexecdir/condor/test/condor_tests/job_core_bigenv_van.cmd
%_libexecdir/condor/test/condor_tests/job_core_compressfiles_std.cmd
%_libexecdir/condor/test/condor_tests/job_core_compressfiles_std.data
%_libexecdir/condor/test/condor_tests/job_core_copytospool_van.cmd
%_libexecdir/condor/test/condor_tests/job_core_coredump-none_std.cmd
%_libexecdir/condor/test/condor_tests/job_core_coredump-none_van.cmd
%_libexecdir/condor/test/condor_tests/job_core_coredump-xfer_van.cmd
%_libexecdir/condor/test/condor_tests/job_core_coredump-yes_std.cmd
%_libexecdir/condor/test/condor_tests/job_core_coredump-yes_van.cmd
%_libexecdir/condor/test/condor_tests/job_core_corefiles_sched.cmd
%_libexecdir/condor/test/condor_tests/job_core_corefiles_van.cmd
%_libexecdir/condor/test/condor_tests/job_core-cpp_exception_std.cmd
%_libexecdir/condor/test/condor_tests/job_core-cpp_mem-alloc_std.cmd
%_libexecdir/condor/test/condor_tests/job_core_crontab.cmd
%_libexecdir/condor/test/condor_tests/job_core_doublejeopardy_sched.cmd
%_libexecdir/condor/test/condor_tests/job_core_doublejeopardy_van.cmd
%_libexecdir/condor/test/condor_tests/job_core_env_java.cmd
%_libexecdir/condor/test/condor_tests/job_core_env_sched.cmd
%_libexecdir/condor/test/condor_tests/job_core_env_van.cmd
%_libexecdir/condor/test/condor_tests/job_core_err_java.cmd
%_libexecdir/condor/test/condor_tests/job_core_err_sched.cmd
%_libexecdir/condor/test/condor_tests/job_core_err_van.cmd
%_libexecdir/condor/test/condor_tests/job_core_getenv_van.cmd
%_libexecdir/condor/test/condor_tests/job_core_hold_java.cmd
%_libexecdir/condor/test/condor_tests/job_core_holdkillsig_sched.cmd
%_libexecdir/condor/test/condor_tests/job_core_holdrelease_sched.cmd
%_libexecdir/condor/test/condor_tests/job_core_holdrelease_van.cmd
%_libexecdir/condor/test/condor_tests/job_core_hold_sched.cmd
%_libexecdir/condor/test/condor_tests/job_core_hold_van.cmd
%_libexecdir/condor/test/condor_tests/job_core_initialdir_java.cmd
%_libexecdir/condor/test/condor_tests/job_core_initialdir_sched.cmd
%_libexecdir/condor/test/condor_tests/job_core_initialdir_van.cmd
%_libexecdir/condor/test/condor_tests/job_core_input.in
%_libexecdir/condor/test/condor_tests/job_core_input_java.cmd
%_libexecdir/condor/test/condor_tests/job_core_input_sched.cmd
%_libexecdir/condor/test/condor_tests/job_core_input_van.cmd
%_libexecdir/condor/test/condor_tests/job_core_killsignal_java.cmd
%_libexecdir/condor/test/condor_tests/job_core_killsignal_sched.cmd
%_libexecdir/condor/test/condor_tests/job_core_killsignal_van.cmd
%_libexecdir/condor/test/condor_tests/job_core_leaveinqueue-false_java.cmd
%_libexecdir/condor/test/condor_tests/job_core_leaveinqueue-false_sched.cmd
%_libexecdir/condor/test/condor_tests/job_core_leaveinqueue-false_van.cmd
%_libexecdir/condor/test/condor_tests/job_core_leaveinqueue-true_java.cmd
%_libexecdir/condor/test/condor_tests/job_core_leaveinqueue-true_sched.cmd
%_libexecdir/condor/test/condor_tests/job_core_leaveinqueue-true_van.cmd
%_libexecdir/condor/test/condor_tests/job_core_macros-dollardollar_van.cmd
%_libexecdir/condor/test/condor_tests/job_core_macros_java.cmd
%_libexecdir/condor/test/condor_tests/job_core_macros_sched.cmd
%_libexecdir/condor/test/condor_tests/job_core_matchlist_van.cmd
%_libexecdir/condor/test/condor_tests/job_core_max-running_local.cmd
%_libexecdir/condor/test/condor_tests/job_core_niceuser_van.cmd
%_libexecdir/condor/test/condor_tests/job_core_onexithold-false_java.cmd
%_libexecdir/condor/test/condor_tests/job_core_onexithold-false_local.cmd
%_libexecdir/condor/test/condor_tests/job_core_onexithold-false_sched.cmd
%_libexecdir/condor/test/condor_tests/job_core_onexithold-false_van.cmd
%_libexecdir/condor/test/condor_tests/job_core_onexithold-true_java.cmd
%_libexecdir/condor/test/condor_tests/job_core_onexithold-true_local.cmd
%_libexecdir/condor/test/condor_tests/job_core_onexithold-true_sched.cmd
%_libexecdir/condor/test/condor_tests/job_core_onexithold-true_van.cmd
%_libexecdir/condor/test/condor_tests/job_core_onexitrem-false_java.cmd
%_libexecdir/condor/test/condor_tests/job_core_onexitrem-false_local.cmd
%_libexecdir/condor/test/condor_tests/job_core_onexitrem-false_sched.cmd
%_libexecdir/condor/test/condor_tests/job_core_onexitrem-false_van.cmd
%_libexecdir/condor/test/condor_tests/job_core_onexitrem-true_java.cmd
%_libexecdir/condor/test/condor_tests/job_core_onexitrem-true_local.cmd
%_libexecdir/condor/test/condor_tests/job_core_onexitrem-true_sched.cmd
%_libexecdir/condor/test/condor_tests/job_core_onexitrem-true_van.cmd
%_libexecdir/condor/test/condor_tests/job_core_output.in
%_libexecdir/condor/test/condor_tests/job_core_output_java.cmd
%_libexecdir/condor/test/condor_tests/job_core_output_sched.cmd
%_libexecdir/condor/test/condor_tests/job_core_output_van.cmd
%_libexecdir/condor/test/condor_tests/job_core_perhold-false_java.cmd
%_libexecdir/condor/test/condor_tests/job_core_perhold-false_local.cmd
%_libexecdir/condor/test/condor_tests/job_core_perhold-false_sched.cmd
%_libexecdir/condor/test/condor_tests/job_core_perhold-false_van.cmd
%_libexecdir/condor/test/condor_tests/job_core_perhold-true_java.cmd
%_libexecdir/condor/test/condor_tests/job_core_perhold-true_local.cmd
%_libexecdir/condor/test/condor_tests/job_core_perhold-true_sched.cmd
%_libexecdir/condor/test/condor_tests/job_core_perhold-true_van.cmd
%_libexecdir/condor/test/condor_tests/job_core_periodicremove_van.cmd
%_libexecdir/condor/test/condor_tests/job_core_perrelease-false_java.cmd
%_libexecdir/condor/test/condor_tests/job_core_perrelease-false_local.cmd
%_libexecdir/condor/test/condor_tests/job_core_perrelease-false_sched.cmd
%_libexecdir/condor/test/condor_tests/job_core_perrelease-false_van.cmd
%_libexecdir/condor/test/condor_tests/job_core_perrelease-true_java.cmd
%_libexecdir/condor/test/condor_tests/job_core_perrelease-true_local.cmd
%_libexecdir/condor/test/condor_tests/job_core_perrelease-true_sched.cmd
%_libexecdir/condor/test/condor_tests/job_core_perrelease-true_van.cmd
%_libexecdir/condor/test/condor_tests/job_core_perremove-false_java.cmd
%_libexecdir/condor/test/condor_tests/job_core_perremove-false_local.cmd
%_libexecdir/condor/test/condor_tests/job_core_perremove-false_sched.cmd
%_libexecdir/condor/test/condor_tests/job_core_perremove-false_van.cmd
%_libexecdir/condor/test/condor_tests/job_core_perremove-true_java.cmd
%_libexecdir/condor/test/condor_tests/job_core_perremove-true_local.cmd
%_libexecdir/condor/test/condor_tests/job_core_perremove-true_sched.cmd
%_libexecdir/condor/test/condor_tests/job_core_perremove-true_van.cmd
%_libexecdir/condor/test/condor_tests/job_core_plus_java.cmd
%_libexecdir/condor/test/condor_tests/job_core_plus_sched.cmd
%_libexecdir/condor/test/condor_tests/job_core_plus_van.cmd
%_libexecdir/condor/test/condor_tests/job_core_priority.data
%_libexecdir/condor/test/condor_tests/job_core_priority_java.cmd
%_libexecdir/condor/test/condor_tests/job_core_priority_java.data
%_libexecdir/condor/test/condor_tests/job_core_priority_van.cmd
%_libexecdir/condor/test/condor_tests/job_core_priority_van.data
%_libexecdir/condor/test/condor_tests/job_core_remote-initialdir_van.cmd
%_libexecdir/condor/test/condor_tests/job_core_remote-initialdir_van.in
%_libexecdir/condor/test/condor_tests/job_core_rmkillsig_sched.cmd
%_libexecdir/condor/test/condor_tests/job_core_sh-loop_van.cmd
%_libexecdir/condor/test/condor_tests/job_core_signal-suicide_sched.cmd
%_libexecdir/condor/test/condor_tests/job_core_signal-suicide_van.cmd
%_libexecdir/condor/test/condor_tests/job_core_time-deferral.cmd
%_libexecdir/condor/test/condor_tests/job_core_time-deferral-tests.cmd
%_libexecdir/condor/test/condor_tests/job_dagman_basic.dag
%_libexecdir/condor/test/condor_tests/job_dagman_basic-node.cmd
%_libexecdir/condor/test/condor_tests/job_dagman_comlog.cmd
%_libexecdir/condor/test/condor_tests/job_dagman_comlog.dag
%_libexecdir/condor/test/condor_tests/job_dagman_fullremove.cmd
%_libexecdir/condor/test/condor_tests/job_dagman_fullremove.dag
%_libexecdir/condor/test/condor_tests/job_dagman_maxpostscripts.cmd
%_libexecdir/condor/test/condor_tests/job_dagman_maxpostscripts.dag
%_libexecdir/condor/test/condor_tests/job_dagman_maxpostscripts-node.cmd
%_libexecdir/condor/test/condor_tests/job_dagman_maxprescripts.cmd
%_libexecdir/condor/test/condor_tests/job_dagman_maxprescripts.dag
%_libexecdir/condor/test/condor_tests/job_dagman_maxprescripts-node.cmd
%_libexecdir/condor/test/condor_tests/job_dagman_prepost.dag
%_libexecdir/condor/test/condor_tests/job_dagman_prepost-node.cmd
%_libexecdir/condor/test/condor_tests/job_dagman_retry.dag
%_libexecdir/condor/test/condor_tests/job_dagman_retry-node.cmd
%_libexecdir/condor/test/condor_tests/job_dagman_throttle.cmd
%_libexecdir/condor/test/condor_tests/job_dagman_throttle.dag
%_libexecdir/condor/test/condor_tests/job_dagman_uncomlog1.cmd
%_libexecdir/condor/test/condor_tests/job_dagman_uncomlog2.cmd
%_libexecdir/condor/test/condor_tests/job_dagman_uncomlog3.cmd
%_libexecdir/condor/test/condor_tests/job_dagman_uncomlog4.cmd
%_libexecdir/condor/test/condor_tests/job_dagman_uncomlog.dag
%_libexecdir/condor/test/condor_tests/job_dagman_unlessexit.cmd
%_libexecdir/condor/test/condor_tests/job_dagman_unlessexit.dag
%_libexecdir/condor/test/condor_tests/job_dagman_xmlcomlog.cmd
%_libexecdir/condor/test/condor_tests/job_dagman_xmlcomlog.dag
%_libexecdir/condor/test/condor_tests/job_dagman_xmluncomlog1.cmd
%_libexecdir/condor/test/condor_tests/job_dagman_xmluncomlog2.cmd
%_libexecdir/condor/test/condor_tests/job_dagman_xmluncomlog3.cmd
%_libexecdir/condor/test/condor_tests/job_dagman_xmluncomlog4.cmd
%_libexecdir/condor/test/condor_tests/job_dagman_xmluncomlog.dag
%_libexecdir/condor/test/condor_tests/job_filexfer_basic.data
%_libexecdir/condor/test/condor_tests/job_filexfer_basic_van.cmd
%_libexecdir/condor/test/condor_tests/job_filexfer_md5-remote_java.cmd
%_libexecdir/condor/test/condor_tests/job_filexfer_md5-remote_van.cmd
%_libexecdir/condor/test/condor_tests/job_filexfer_sandbox-empty_van.cmd
%_libexecdir/condor/test/condor_tests/job_filexfer_streamerr_van.cmd
%_libexecdir/condor/test/condor_tests/job_filexfer_streamout_van.cmd
%_libexecdir/condor/test/condor_tests/job_filexfer_trans-excut-true_van.cmd
%_libexecdir/condor/test/condor_tests/job_filexfer_trans-nodflts_van.cmd
%_libexecdir/condor/test/condor_tests/job_filexfer_twosets_van.cmd
%_libexecdir/condor/test/condor_tests/job_filexfer_withvacate-nofiles_van.cmd
%_libexecdir/condor/test/condor_tests/job_flocking_to.cmd
%_libexecdir/condor/test/condor_tests/job_had_basic.cfg
%_libexecdir/condor/test/condor_tests/job_had_basic.locpostsrc.template
%_libexecdir/condor/test/condor_tests/job_ligo_x86-64-chkpttst.cmd
%_libexecdir/condor/test/condor_tests/job_quill_basic.cmd
%_libexecdir/condor/test/condor_tests/job_replication_basic.cfg
%_libexecdir/condor/test/condor_tests/job_replication_basic.localpostsrc
%_libexecdir/condor/test/condor_tests/job_replication_big.cfg
%_libexecdir/condor/test/condor_tests/job_replication_big.localpostsrc
%_libexecdir/condor/test/condor_tests/job_rsc_all-syscalls_std.cmd
%_libexecdir/condor/test/condor_tests/job_rsc_binary-io_std.cmd
%_libexecdir/condor/test/condor_tests/job_rsc_fcntl_std.cmd
%_libexecdir/condor/test/condor_tests/job_rsc_f-direct-write_std.cmd
%_libexecdir/condor/test/condor_tests/job_rsc_f-direct-write_std.f
%_libexecdir/condor/test/condor_tests/job_rsc_fgets_std.cmd
%_libexecdir/condor/test/condor_tests/job_rsc_fread_std.cmd
%_libexecdir/condor/test/condor_tests/job_rsc_fstream_std.cmd
%_libexecdir/condor/test/condor_tests/job_rsc_ftell_std.cmd
%_libexecdir/condor/test/condor_tests/job_rsc_getdirentries_std.cmd
%_libexecdir/condor/test/condor_tests/job_rsc_hello_std.cmd
%_libexecdir/condor/test/condor_tests/job_rsc_open-N-serial_std.cmd
%_libexecdir/condor/test/condor_tests/job_rsc_stat_std.cmd
%_libexecdir/condor/test/condor_tests/job_rsc_true-false_std.cmd
%_libexecdir/condor/test/condor_tests/job_rsc_truncate_std.cmd
%_libexecdir/condor/test/condor_tests/job_rsc_zero-calloc_std.cmd
%_libexecdir/condor/test/condor_tests/job_schedd_job-tracking_van.cmd
%_libexecdir/condor/test/condor_tests/job_schedd_restart-holdjobs-ok.cmd
%_libexecdir/condor/test/condor_tests/job_schedd_restart-holdjobs-ok.template
%_libexecdir/condor/test/condor_tests/job_schedd_restart-runningjobs-ok.cmd
%_libexecdir/condor/test/condor_tests/job_schedd_restart-runningjobs-ok.template
%_libexecdir/condor/test/condor_tests/job_startd_multimatch.ad
%_libexecdir/condor/test/condor_tests/job_startd_multimatch.cmd
%_libexecdir/condor/test/condor_tests/job_stork_file-file.stork
%_libexecdir/condor/test/condor_tests/lib_auth_config_tests/test_auth_1_config
%_libexecdir/condor/test/condor_tests/lib_auth_config_tests/test_auth_1_input
%_libexecdir/condor/test/condor_tests/lib_auth_config_tests/test_auth_2a_config
%_libexecdir/condor/test/condor_tests/lib_auth_config_tests/test_auth_2a_input
%_libexecdir/condor/test/condor_tests/lib_auth_config_tests/test_auth_2b_config
%_libexecdir/condor/test/condor_tests/lib_auth_config_tests/test_auth_2b_input
%_libexecdir/condor/test/condor_tests/lib_auth_config_tests/test_auth_2c_config
%_libexecdir/condor/test/condor_tests/lib_auth_config_tests/test_auth_2c_input
%_libexecdir/condor/test/condor_tests/lib_auth_config_tests/test_auth_2d_config
%_libexecdir/condor/test/condor_tests/lib_auth_config_tests/test_auth_2d_input
%_libexecdir/condor/test/condor_tests/lib_auth_config_tests/test_auth_2e_config
%_libexecdir/condor/test/condor_tests/lib_auth_config_tests/test_auth_2e_input
%_libexecdir/condor/test/condor_tests/lib_auth_config_tests/test_auth_2f_config
%_libexecdir/condor/test/condor_tests/lib_auth_config_tests/test_auth_2f_input
%_libexecdir/condor/test/condor_tests/lib_auth_config_tests/test_auth_2g_config
%_libexecdir/condor/test/condor_tests/lib_auth_config_tests/test_auth_2g_input
%_libexecdir/condor/test/condor_tests/lib_auth_config_tests/test_auth_2h_config
%_libexecdir/condor/test/condor_tests/lib_auth_config_tests/test_auth_2h_input
%_libexecdir/condor/test/condor_tests/lib_auth_config_tests/test_auth_3_config
%_libexecdir/condor/test/condor_tests/lib_auth_config_tests/test_auth_3_input
%_libexecdir/condor/test/condor_tests/lib_auth_config_tests/test_auth_4_config
%_libexecdir/condor/test/condor_tests/lib_auth_config_tests/test_auth_4_input
%_libexecdir/condor/test/condor_tests/lib_auth_config_tests/test_auth_5_config
%_libexecdir/condor/test/condor_tests/lib_auth_config_tests/test_auth_5_input
%_libexecdir/condor/test/condor_tests/lib_auth_protocol-ctb.cmd
%_libexecdir/condor/test/condor_tests/lib_auth_protocol-fs.cmd
%_libexecdir/condor/test/condor_tests/lib_auth_protocol-gsi.cmd
%_libexecdir/condor/test/condor_tests/lib_auth_protocol-krb.cmd
%_libexecdir/condor/test/condor_tests/lib_auth_protocol-negot.cmd
%_libexecdir/condor/test/condor_tests/lib_auth_protocol-negot.data
%_libexecdir/condor/test/condor_tests/lib_auth_protocol-negot-prt2.cmd
%_libexecdir/condor/test/condor_tests/lib_auth_protocol-negot-prt2.data
%_libexecdir/condor/test/condor_tests/lib_auth_protocol-negot-prt3.cmd
%_libexecdir/condor/test/condor_tests/lib_auth_protocol-negot-prt3.data
%_libexecdir/condor/test/condor_tests/lib_auth_protocol-negot-prt4.cmd
%_libexecdir/condor/test/condor_tests/lib_auth_protocol-negot-prt4.data
%_libexecdir/condor/test/condor_tests/lib_auth_protocol-pw.cmd
%_libexecdir/condor/test/condor_tests/lib_auth_protocol-ssl.cmd
%_libexecdir/condor/test/condor_tests/lib_chirpio_van.cmd
%_libexecdir/condor/test/condor_tests/lib_eventlog.template
%_libexecdir/condor/test/condor_tests/lib_procapi_cputracking-snapshot.cmd
%_libexecdir/condor/test/condor_tests/lib_procapi_pidtracking-byenv.cmd
%_libexecdir/condor/test/condor_tests/lib_procapi_pidtracking-snapshot.cmd
%_libexecdir/condor/test/condor_tests/lib_userlog.cmd
%_libexecdir/condor/test/condor_tests/list_all
%_libexecdir/condor/test/condor_tests/list_btdebug
%_libexecdir/condor/test/condor_tests/list_condorc
%_libexecdir/condor/test/condor_tests/list_core
%_libexecdir/condor/test/condor_tests/list_dagman
%_libexecdir/condor/test/condor_tests/list_env
%_libexecdir/condor/test/condor_tests/list_filexfer
%_libexecdir/condor/test/condor_tests/list_framework
%_libexecdir/condor/test/condor_tests/list_full
%_libexecdir/condor/test/condor_tests/list_lib
%_libexecdir/condor/test/condor_tests/list_local
%_libexecdir/condor/test/condor_tests/list_long
%_libexecdir/condor/test/condor_tests/list_quick
%_libexecdir/condor/test/condor_tests/list_quicknolink
%_libexecdir/condor/test/condor_tests/list_simple
%_libexecdir/condor/test/condor_tests/list_testclass
%_libexecdir/condor/test/condor_tests/perf_busy_lynn_100_100_500_sched.cmd
%_libexecdir/condor/test/condor_tests/perf_jobs_sue_10_10_30_van.cmd
%_libexecdir/condor/test/condor_tests/perf_xfer_deb_10_10_30_van.cmd
%_libexecdir/condor/test/condor_tests/README
%_libexecdir/condor/test/condor_tests/README.filenames
%_libexecdir/condor/test/condor_tests/README.imake
%_libexecdir/condor/test/condor_tests/README.running
%_libexecdir/condor/test/condor_tests/README.testclass
%_libexecdir/condor/test/condor_tests/testmethods.txt
%_libexecdir/condor/test/condor_tests/TimeoutChanges
%_libexecdir/condor/test/condor_tests/Windows_list
%_libexecdir/condor/test/condor_tests/Windows_testing
%_libexecdir/condor/test/condor_tests/WISDOM.C-tests
%_libexecdir/condor/test/condor_tests/WISDOM.Fortran
%_libexecdir/condor/test/condor_tests/x_auth_poolpasswd
%_libexecdir/condor/test/condor_tests/x_basicparallel_locconfigpostsrc
%_libexecdir/condor/test/condor_tests/x_basicparallel-security_locconfigpostsrc
%_libexecdir/condor/test/condor_tests/x_cmdrunforever.cmd
%_libexecdir/condor/test/condor_tests/x_cmdrunforever.cmd2
%_libexecdir/condor/test/condor_tests/x_cmdrunforever.cmd3
%_libexecdir/condor/test/condor_tests/x_cmdrunforever.cmd4
%_libexecdir/condor/test/condor_tests/x_cmdstartonhold.cmd
%_libexecdir/condor/test/condor_tests/x_condorc_locconfigpostsrc
%_libexecdir/condor/test/condor_tests/x_condor_config_template
%_libexecdir/condor/test/condor_tests/x_cpusnaptrack_configpostsrc
%_libexecdir/condor/test/condor_tests/x_data.in
%_libexecdir/condor/test/condor_tests/x_flockto_configpostsrc.template
%_libexecdir/condor/test/condor_tests/x_hadutilities.pm
%_libexecdir/condor/test/condor_tests/x_hello.in
%_libexecdir/condor/test/condor_tests/x_java_CondorEcho.java
%_libexecdir/condor/test/condor_tests/x_java_CopyFilePlus.java
%_libexecdir/condor/test/condor_tests/x_java_Property.java
%_libexecdir/condor/test/condor_tests/x_java_ReadStdin.java
%_libexecdir/condor/test/condor_tests/x_java_RenameFile.java
%_libexecdir/condor/test/condor_tests/x_java_Sleep.java
%_libexecdir/condor/test/condor_tests/x_job_quill_basic.template
%_libexecdir/condor/test/condor_tests/x_job_quill_supw
%_libexecdir/condor/test/condor_tests/x_lib_auth-gsi_keys.tgz
%_libexecdir/condor/test/condor_tests/x_lib_auth-ssl_keys.tgz
%_libexecdir/condor/test/condor_tests/x_lib_eventlog_config_postsrc.template
%_libexecdir/condor/test/condor_tests/x_lib_eventlog.expected
%_libexecdir/condor/test/condor_tests/x_lib_eventlog-xml_config_postsrc.template
%_libexecdir/condor/test/condor_tests/x_param.basicparallel
%_libexecdir/condor/test/condor_tests/x_param.basicparallel-security
%_libexecdir/condor/test/condor_tests/x_param.basic_personal
%_libexecdir/condor/test/condor_tests/x_param.cmdq-multi
%_libexecdir/condor/test/condor_tests/x_param.cmdq-multi.template
%_libexecdir/condor/test/condor_tests/x_param.cmdstatus-multi
%_libexecdir/condor/test/condor_tests/x_param.cmdstatus-multi.template
%_libexecdir/condor/test/condor_tests/x_param.condorclocal
%_libexecdir/condor/test/condor_tests/x_param.condorcmiddle
%_libexecdir/condor/test/condor_tests/x_param.condorcremote
%_libexecdir/condor/test/condor_tests/x_param.cputracking-snapshot
%_libexecdir/condor/test/condor_tests/x_param.flocktestflockto
%_libexecdir/condor/test/condor_tests/x_param.flocktestlocal
%_libexecdir/condor/test/condor_tests/x_param.had
%_libexecdir/condor/test/condor_tests/x_param.libeventlog
%_libexecdir/condor/test/condor_tests/x_param.libeventlog-xml
%_libexecdir/condor/test/condor_tests/x_param.periodicremove
%_libexecdir/condor/test/condor_tests/x_param.protocol-ctb.template
%_libexecdir/condor/test/condor_tests/x_param.protocol-fs.template
%_libexecdir/condor/test/condor_tests/x_param.protocol-gsi.template
%_libexecdir/condor/test/condor_tests/x_param.protocol-krb.template
%_libexecdir/condor/test/condor_tests/x_param.protocol-negot.template
%_libexecdir/condor/test/condor_tests/x_param.protocol-pw
%_libexecdir/condor/test/condor_tests/x_param.protocol-ssl.template
%_libexecdir/condor/test/condor_tests/x_param.quill
%_libexecdir/condor/test/condor_tests/x_param.replication
%_libexecdir/condor/test/condor_tests/x_param.scheddrestart
%_libexecdir/condor/test/condor_tests/x_param.startdmultimatch
%_libexecdir/condor/test/condor_tests/x_param.storksrvr
%_libexecdir/condor/test/condor_tests/x_perf_auto_paraam_template
%_libexecdir/condor/test/condor_tests/x_perf_auto_param.deb
%_libexecdir/condor/test/condor_tests/x_perf_auto_param.lynn
%_libexecdir/condor/test/condor_tests/x_perf_auto_param.sue
%_libexecdir/condor/test/condor_tests/x_perf_autoscale_cmd_template
%_libexecdir/condor/test/condor_tests/x_perf_autoscale.man
%_libexecdir/condor/test/condor_tests/x_perf_Busy.java
%_libexecdir/condor/test/condor_tests/x_perf_CopyFile.java
%_libexecdir/condor/test/condor_tests/x_perf_Sleep.java
%_libexecdir/condor/test/condor_tests/x_periodicremove_locconfigpostsrc
%_libexecdir/condor/test/condor_tests/x_postgress_quill.conf
%_libexecdir/condor/test/condor_tests/x_quill_config_postsrc.template
%_libexecdir/condor/test/condor_tests/x_quill_Expect-1.20.tar.gz
%_libexecdir/condor/test/condor_tests/x_quill_IO-Tty-1.07.tar.gz
%_libexecdir/condor/test/condor_tests/x_quill_readline-5.2.tar.gz
%_libexecdir/condor/test/condor_tests/x_read_joblog.readme
%_libexecdir/condor/test/condor_tests/x_sanitysubmit.cmd
%_libexecdir/condor/test/condor_tests/x_secctb_configpostsrc
%_libexecdir/condor/test/condor_tests/x_secfs_configpostsrc
%_libexecdir/condor/test/condor_tests/x_secgsi_configpostsrc.template
%_libexecdir/condor/test/condor_tests/x_seckrb_configpostsrc
%_libexecdir/condor/test/condor_tests/x_secneg_clN_dmnN_secprepostsrc
%_libexecdir/condor/test/condor_tests/x_secneg_clN_dmnO_secprepostsrc
%_libexecdir/condor/test/condor_tests/x_secneg_clN_dmnP_secprepostsrc
%_libexecdir/condor/test/condor_tests/x_secneg_clN_dmnR_secprepostsrc
%_libexecdir/condor/test/condor_tests/x_secneg_clO_dmnN_secprepostsrc
%_libexecdir/condor/test/condor_tests/x_secneg_clO_dmnO_secprepostsrc
%_libexecdir/condor/test/condor_tests/x_secneg_clO_dmnP_secprepostsrc
%_libexecdir/condor/test/condor_tests/x_secneg_clO_dmnR_secprepostsrc
%_libexecdir/condor/test/condor_tests/x_secneg_clP_dmnN_secprepostsrc
%_libexecdir/condor/test/condor_tests/x_secneg_clP_dmnO_secprepostsrc
%_libexecdir/condor/test/condor_tests/x_secneg_clP_dmnP_secprepostsrc
%_libexecdir/condor/test/condor_tests/x_secneg_clP_dmnR_secprepostsrc
%_libexecdir/condor/test/condor_tests/x_secneg_clR_dmnN_secprepostsrc
%_libexecdir/condor/test/condor_tests/x_secneg_clR_dmnO_secprepostsrc
%_libexecdir/condor/test/condor_tests/x_secneg_clR_dmnP_secprepostsrc
%_libexecdir/condor/test/condor_tests/x_secneg_clR_dmnR_secprepostsrc
%_libexecdir/condor/test/condor_tests/x_secneg_configpostsrc
%_libexecdir/condor/test/condor_tests/x_secpw_configpostsrc.template
%_libexecdir/condor/test/condor_tests/x_secpw_mapfile.template
%_libexecdir/condor/test/condor_tests/x_secssl_configpostsrc.template
%_libexecdir/condor/test/condor_tests/x_soap_job_tests.tar.gz
%_libexecdir/condor/test/condor_tests/x_Test_CA.tar.gz
%_libexecdir/condor/test/testbin_dir/libcondorapi.so
%_libexecdir/condor/test/condor_tests/job_core_perrelease-false_local.template
%_libexecdir/condor/test/condor_tests/job_core_perrelease-true_local.template
%_libexecdir/condor/test/condor_tests/x_param.locperrelease
%_libexecdir/condor/test/condor_tests/x_param.vancrontab
%_libexecdir/condor/test/condor_tests/x_fetch_configpostsrc.template
%_libexecdir/condor/test/condor_tests/x_param.fetch-basic
%_libexecdir/condor/test/condor_tests/x_workfetch_classad.1.template
%_libexecdir/condor/test/condor_tests/x_fetchwork_scripts.tar.gz


%post -n condor
/sbin/chkconfig --add condor
/sbin/ldconfig


%preun -n condor
if [ $1 = 0 ]; then
  /sbin/service condor stop >/dev/null 2>&1 || :
  /sbin/chkconfig --del condor
fi


%postun -n condor
if [ "$1" -ge "1" ]; then
  /sbin/service condor condrestart >/dev/null 2>&1 || :
fi
/sbin/ldconfig


%changelog
* Wed Aug  6 2008  <mfarrellee@redhat> - 7.0.4-4
- Fixed /etc/condor/condor_config to not specify CONDOR_HOST
- Assigned condor uid:gid is 64:64, BZ458069

* Wed Aug 6 2008  <rrati@redhat.com> - 7.0.4-3
- Resolved: BZ457976
- Resolved: BZ458110

* Wed Jul 30 2008  <mfarrellee@redhat> - 7.0.4-2
- Resolved: BZ456478

* Wed Jul 23 2008  <mfarrellee@redhat> - 7.0.4-1
- Rebased on UW's 7.0.4 source release, includes fixes and perf enhancements
- First release with an Integration-Branch patch: fixes, opts, hooks, router, EC2
- Added --with-buildid to configure, addresses version info
- Fixed up condor_tests packaging to include new tests
- Packaged sql scripts, BZ455338
- Resolves: BZ455338, BZ452512, BZ452515, BZ456080, BZ449043, BZ447830
- Stopped using condor_configure
- Added python dependency, for condor_router_history

* Wed Jul 16 2008  <mfarrellee@redhat> - 7.0.2-5
- Added SCHEDD_NAME fix for HA Schedds
- Updated Job Hooks feature, -when-root -default-iwd fix integrated
- Added fix for negotiator crash
- Updated EC2 feature

* Thu Jul 3 2008  <rrati@redhat.com> - 7.0.2-4
- Cleaned up the job hooks when running as root fix

* Thu Jul 3 2008  <rrati@redhat.com> - 7.0.2-3
- Added job hooks support
- Added fix for job hooks when running as root
- Added fix for a missing IWD in the job description
- Moved some .pl and .run files to have execute permissions for consistency

* Thu Jun 12 2008  <mfarrellee@redhat> - 7.0.2-2
- New, safer, threading code for amazon-gahp
- EC2 resource leak from condor_gridmanager fixed

* Wed Jun 11 2008  <mfarrellee@redhat> - 7.0.2-1
- Updated to 7.0.2 release
- Moved modifications of condor_config to condor_config.generic patch

* Tue Jun 10 2008  <mfarrellee@redhat> - 7.0.1-12
- Resolved 450316, Proxy Support
- Rebased EC2.patch for new recovery code, parameter name changes, ...

* Fri Jun  6 2008  <mfarrellee@redhat> - 7.0.1-11
- Added TP notice

* Thu Jun  5 2008  <mfarrellee@redhat> - 7.0.1-10
- Fixed for RHEL 4, cannot apply EC2-Amazon-Imakefile.patch

* Thu Jun  5 2008  <mfarrellee@redhat> - 7.0.1-9
- Removed UID/FILESYSTEM_DOMAIN from condor_config.local
- Cleaned conditionals around patches
- Changed HOSTALLOW_WRITE default to $(FULL_HOSTNAME), i.e. presonal pool
- Updated EC2 to use SOAP instead of REST: removes Perl deps, adds RHEL 4 EC2 support

* Thu May 22 2008  <mfarrellee@redhat> - 7.0.1-8
- Added new ClassAds and better-analyze support

* Wed May 21 2008  <mfarrellee@redhat> - 7.0.1-7
- Init script modified on RHEL 4, where --pidfile and -p are not supported

* Wed May  7 2008  <mfarrellee@redhat> - 7.0.1-6
- Resolved: (EC2.patch) bz440699, bz440520, bz445626, bz440516, bz440531, bz440524, bz446749, bz446319, bz440515, bz446740
- Fixed dependencies, no EC2 on RHEL 4

* Wed Apr  2 2008  <mfarrellee@redhat> - 7.0.1-5
- Added preliminary EC2 support
- Cleaned up patch names and orders

* Wed Mar 12 2008  <rrati@redhat> - 7.0.1-4
- Have batch_test.pl exit condor_master process it starts when it exits

* Fri Mar  7 2008  <rrati@redhat> - 7.0.1-3
- Create a package that contains the testing materials for condor

* Fri Mar  7 2008  <mfarrellee@redhat> - 7.0.1-2
- Conditionally use custom imake when on RHEL 4, which does not have
  imake packaged
- Removed use of find to fix execute permissions on source files,
  fixed upstream
- Added disable_glibc_version_check patch to avoid problems with RHEL
  4, and many other distro's, version of glibc
- Removed f9_glibc_detection patch in favor of
  --disable-glibc-version-check to configure
- Disabled KRB5 support on RHEL 4, due to compliation errors with
  krb5-1.3.4
- Disabled SMP_NUM_JOBS because of dependency issues

* Wed Feb 27 2008  <mfarrellee@redhat> - 7.0.1-1
- Updated to UW's 7.0.1 release, source was 223.4MB
- Updated generate-tarball.sh to handle condor-7.0.1 directory name
  instead of condor_src-7.0.1 in the upstream source tarball
- Removed lsb_init.patch, accepted upstream
- Removed configure_with_to_enable.patch, accepted upstream
- Removed enable_gcc_version_check.patch, accepted upstream
- Removed f9_gcc_detection.patch, using --disable-gcc-version-check
- Removed modification of config/site.def, it was unnecessary
- Re-enabled use of ?_smp_mflags

* Wed Feb 27 2008  <mfarrellee@redhat> - 7.0.0-8
- Inclusion of patch enable_gcc_version_check to allow for disabling
  check for gcc version and resulting errors, useful when dealing with
  new versions of gcc, and will allow for removal of f9_gcc_detection
  patch
- Added patch configure_with_to_enable to change some AC_ARG_WITH to,
  more proper, AC_ARG_ENABLE
- Removed gsoap_nonamespaces patch in favor of gsoap 2.7.10-2 or
  greater
- Added patch gridmanager_without_globus to allow for compliation of
  condor_gridmanager and handlers for different gahps. This means
  functionality is determined at runtime instead of compile time.
- Added patch avoid_gsoap_linking to link only executables requiring
  gsoap against libgsoap, patch contributed by rrati@redhat
- Added patch separate_postgresql_in_build to begin linking postgresql
  only against those programs that need it, contributed by
  rrati@redhat

* Thu Feb 14 2008  <mfarrellee@redhat> - 7.0.0-7
- Some changes to config files made during install are now done in a
  patch during prep, condor_config.generic.patch. This should simplify
  install and resolve an issue with the generated config file for
  tests.
- Init Script Update: contains improved lsb logic; fixes BZ432639; no
  longer on by default; now patched into source

* Mon Feb 11 2008  <mfarrellee@redhat> - 7.0.0-6
- Added note about how to download the source
- Added generate-tarball.sh script

* Sun Feb 10 2008  <mfarrellee@redhat> - 7.0.0-5
- The gsoap package is compiled with --disable-namespaces, which means
  soap_set_namespaces is required after each soap_init. The
  gsoap_nonamespaces.patch handles this.

* Fri Feb  8 2008  <mfarrellee@redhat> - 7.0.0-4
- Added patch to detect GCC 4.3.0 on F9
- Added patch to detect GLIBC 2.7.90 on F9
- Added BuildRequires: autoconf to allow for regeneration of configure
  script after GCC 4.3.0 detection and GLIBC 2.7.90 patches are
  applied
- Condor + GCC 4.3.0 + -O2 results in an internal compiler error
  (BZ 432090), so -O2 is removed from optflags for the time
  being. Thanks to Mike Bonnet for the suggestion on how to filter
  -O2.

* Tue Jan 22 2008  <mfarrellee@redhat> - 7.0.0-3
- Update to UW's really-final source for Condor 7.0.0 stable series
  release. It is based on the 72173 build with minor changes to the
  configure.ac related to the SRB external version.
- In addition to removing externals from the UW tarball, the NTconfig
  directory was removed because it had not gone through IP audit.

* Tue Jan 22 2008  <mfarrellee@redhat> - 7.0.0-2
- Update to UW's final source for Condor 7.0.0 stable series release

* Thu Jan 10 2008  <mfarrellee@redhat> - 7.0.0-1
- Initial package of Condor's stable series under ASL 2.0
- is_clipped.patch replaced with --without-full-port option to configure
- zlib_is_soft.patch removed, outdated by configure.ac changes
- removed autoconf dependency needed for zlib_is_soft.patch

* Tue Dec  4 2007  <mfarrellee@redhat> - 6.9.5-2
- SELinux was stopping useradd in pre because files specified root as
  the group owner for /var/lib/condor, fixed, much thanks to Phil Knirsch

* Fri Nov 30 2007  <mfarrellee@redhat> - 6.9.5-1
- Fixed release tag
- Added gSOAP support and packaged WSDL files

* Thu Nov 29 2007  <mfarrellee@redhat> - 6.9.5-0.2
- Packaged LSB init script
- Changed pre to not create the condor user's home directory, it is
  now a directory owned by the package

* Thu Nov 29 2007  <mfarrellee@redhat> - 6.9.5-0.1
- Condor 6.9.5 release, the 7.0.0 stable series candidate
- Removed x86_64_no_multilib-200711091700cvs.patch, merged upstream
- Added patch to make zlib a soft requirement, which it should be
- Disabled use of smp_mflags because of make dependency issues
- Explicitly not packaging WSDL files until the SOAP APIs are available

* Tue Nov 20 2007  <mfarrellee@redhat> - 6.9.5-0.3.200711091700cvs
- Rebuild for repo inheritance update: dependencies are now pulled
  from RHEL 5 U1 before RH Application Stack

* Thu Nov 15 2007 <mfarrellee@redhat> - 6.9.5-0.2.200711091700cvs
- Added support for building on x86_64 without multilib packages
- Made the install section more flexible, reduced need for
  make_final_tarballs to be updated

* Fri Nov 9 2007 <mfarrellee@redhat> - 6.9.5-0.1.200711091700cvs
- Working source with new ASL 2.0 license

* Fri Nov 9 2007 <mfarrellee@redhat> - 6.9.5-0.1.200711091330cvs
- Source is now stamped ASL 2.0, as of Nov 9 2007 1:30PM Central
- Changed license to ASL 2.0
- Fixed find in prep to work if no files have bad permissions
- Changed the name of the LICENSE file to match was is now release in
  the source tarball

* Tue Nov 6 2007  <mfarrellee@redhat> - 6.9.5-0.1.rc
- Added m4 dependency not in RHEL 5.1's base
- Changed chmod a-x script to use find as more files appear to have
  improper execute bits set
- Added ?dist to Release:
- condor_privsep became condor_root_switchboard

* Tue Sep 11 2007  <mfarrellee@redhat> - 6.9.5-0.3.20070907cvs
- Instead of releasing libcondorapi.so, which is improperly created
  and poorly versioned, we release libcondorapi.a, which is apparently
  more widely used, in a -static package
- Instead of installing the stripped tarball, the unstripped is now
  installed, which gives a nice debuginfo package
- Found and fixed permissions problems on a number of src files,
  issue raised by rpmlint on the debuginfo package

* Mon Sep 10 2007  <mfarrellee@redhat> - 6.9.5-0.2.20070907cvs
- Updated pre section to create condor's home directory with adduser, and
  removed _var/lib/condor from files section
- Added doc LICENSE.TXT to all files sections
- Shortened lines longer than 80 characters in this spec (except the sed line)
- Changed install section so untar'ing a release can handle fedora7 or fedora8
- Simplified the site.def and config file updates (sed + mv over mv + sed + rm)
- Added a patch (fedora_rawhide_7.91-20070907cvs.patch) to support building on
  a fedora 7.91 (current Rawhide) release
- Moved the examples from /usr/share/doc/condor... into builddir and just
  marked them as documentation
- Added a number of dir directives to force all files to be listed, no implicit
  inclusion

* Fri Sep  7 2007  <mfarrellee@redhat> - 6.9.5-0.1.20070907cvs
- Initial release
